# coding: utf-8

# flake8: noqa
"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    The version of the OpenAPI document: 2024-10-15
    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from openapi_client.models.api_job_error_payload import APIJobErrorPayload
from openapi_client.models.account_enum import AccountEnum
from openapi_client.models.account_response_object_resource import AccountResponseObjectResource
from openapi_client.models.account_response_object_resource_attributes import AccountResponseObjectResourceAttributes
from openapi_client.models.attribution_enum import AttributionEnum
from openapi_client.models.audiences_sub_object import AudiencesSubObject
from openapi_client.models.back_in_stock_subscription_enum import BackInStockSubscriptionEnum
from openapi_client.models.base_event_create_query_resource_object import BaseEventCreateQueryResourceObject
from openapi_client.models.base_event_create_query_resource_object_attributes import BaseEventCreateQueryResourceObjectAttributes
from openapi_client.models.bulk_profile_suppressions_create_job_response_object_resource import BulkProfileSuppressionsCreateJobResponseObjectResource
from openapi_client.models.bulk_profile_suppressions_create_job_response_object_resource_attributes import BulkProfileSuppressionsCreateJobResponseObjectResourceAttributes
from openapi_client.models.bulk_profile_suppressions_remove_job_response_object_resource import BulkProfileSuppressionsRemoveJobResponseObjectResource
from openapi_client.models.campaign_clone_query import CampaignCloneQuery
from openapi_client.models.campaign_clone_query_resource_object import CampaignCloneQueryResourceObject
from openapi_client.models.campaign_clone_query_resource_object_attributes import CampaignCloneQueryResourceObjectAttributes
from openapi_client.models.campaign_create_query import CampaignCreateQuery
from openapi_client.models.campaign_create_query_resource_object import CampaignCreateQueryResourceObject
from openapi_client.models.campaign_create_query_resource_object_attributes import CampaignCreateQueryResourceObjectAttributes
from openapi_client.models.campaign_create_query_resource_object_attributes_campaign_messages import CampaignCreateQueryResourceObjectAttributesCampaignMessages
from openapi_client.models.campaign_enum import CampaignEnum
from openapi_client.models.campaign_message_assign_template_query import CampaignMessageAssignTemplateQuery
from openapi_client.models.campaign_message_assign_template_query_resource_object import CampaignMessageAssignTemplateQueryResourceObject
from openapi_client.models.campaign_message_assign_template_query_resource_object_relationships import CampaignMessageAssignTemplateQueryResourceObjectRelationships
from openapi_client.models.campaign_message_assign_template_query_resource_object_relationships_template import CampaignMessageAssignTemplateQueryResourceObjectRelationshipsTemplate
from openapi_client.models.campaign_message_assign_template_query_resource_object_relationships_template_data import CampaignMessageAssignTemplateQueryResourceObjectRelationshipsTemplateData
from openapi_client.models.campaign_message_create_query_resource_object import CampaignMessageCreateQueryResourceObject
from openapi_client.models.campaign_message_create_query_resource_object_attributes import CampaignMessageCreateQueryResourceObjectAttributes
from openapi_client.models.campaign_message_enum import CampaignMessageEnum
from openapi_client.models.campaign_message_partial_update_query import CampaignMessagePartialUpdateQuery
from openapi_client.models.campaign_message_partial_update_query_resource_object import CampaignMessagePartialUpdateQueryResourceObject
from openapi_client.models.campaign_message_partial_update_query_resource_object_attributes import CampaignMessagePartialUpdateQueryResourceObjectAttributes
from openapi_client.models.campaign_message_response_object_resource import CampaignMessageResponseObjectResource
from openapi_client.models.campaign_message_response_object_resource_attributes import CampaignMessageResponseObjectResourceAttributes
from openapi_client.models.campaign_partial_update_query import CampaignPartialUpdateQuery
from openapi_client.models.campaign_partial_update_query_resource_object import CampaignPartialUpdateQueryResourceObject
from openapi_client.models.campaign_partial_update_query_resource_object_attributes import CampaignPartialUpdateQueryResourceObjectAttributes
from openapi_client.models.campaign_recipient_estimation_enum import CampaignRecipientEstimationEnum
from openapi_client.models.campaign_recipient_estimation_job_create_query import CampaignRecipientEstimationJobCreateQuery
from openapi_client.models.campaign_recipient_estimation_job_create_query_resource_object import CampaignRecipientEstimationJobCreateQueryResourceObject
from openapi_client.models.campaign_recipient_estimation_job_enum import CampaignRecipientEstimationJobEnum
from openapi_client.models.campaign_recipient_estimation_job_response_object_resource import CampaignRecipientEstimationJobResponseObjectResource
from openapi_client.models.campaign_recipient_estimation_job_response_object_resource_attributes import CampaignRecipientEstimationJobResponseObjectResourceAttributes
from openapi_client.models.campaign_recipient_estimation_response_object_resource import CampaignRecipientEstimationResponseObjectResource
from openapi_client.models.campaign_recipient_estimation_response_object_resource_attributes import CampaignRecipientEstimationResponseObjectResourceAttributes
from openapi_client.models.campaign_response_object_resource import CampaignResponseObjectResource
from openapi_client.models.campaign_response_object_resource_attributes import CampaignResponseObjectResourceAttributes
from openapi_client.models.campaign_send_job_create_query import CampaignSendJobCreateQuery
from openapi_client.models.campaign_send_job_create_query_resource_object import CampaignSendJobCreateQueryResourceObject
from openapi_client.models.campaign_send_job_enum import CampaignSendJobEnum
from openapi_client.models.campaign_send_job_partial_update_query import CampaignSendJobPartialUpdateQuery
from openapi_client.models.campaign_send_job_partial_update_query_resource_object import CampaignSendJobPartialUpdateQueryResourceObject
from openapi_client.models.campaign_send_job_partial_update_query_resource_object_attributes import CampaignSendJobPartialUpdateQueryResourceObjectAttributes
from openapi_client.models.campaign_send_job_response_object_resource import CampaignSendJobResponseObjectResource
from openapi_client.models.campaign_send_job_response_object_resource_attributes import CampaignSendJobResponseObjectResourceAttributes
from openapi_client.models.campaign_values_report_enum import CampaignValuesReportEnum
from openapi_client.models.campaign_values_request_dto import CampaignValuesRequestDTO
from openapi_client.models.campaign_values_request_dto_resource_object import CampaignValuesRequestDTOResourceObject
from openapi_client.models.campaign_values_request_dto_resource_object_attributes import CampaignValuesRequestDTOResourceObjectAttributes
from openapi_client.models.catalog_category_bulk_create_job_enum import CatalogCategoryBulkCreateJobEnum
from openapi_client.models.catalog_category_bulk_delete_job_enum import CatalogCategoryBulkDeleteJobEnum
from openapi_client.models.catalog_category_bulk_update_job_enum import CatalogCategoryBulkUpdateJobEnum
from openapi_client.models.catalog_category_create_job_create_query import CatalogCategoryCreateJobCreateQuery
from openapi_client.models.catalog_category_create_job_create_query_resource_object import CatalogCategoryCreateJobCreateQueryResourceObject
from openapi_client.models.catalog_category_create_job_create_query_resource_object_attributes import CatalogCategoryCreateJobCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_category_create_job_create_query_resource_object_attributes_categories import CatalogCategoryCreateJobCreateQueryResourceObjectAttributesCategories
from openapi_client.models.catalog_category_create_job_response_object_resource import CatalogCategoryCreateJobResponseObjectResource
from openapi_client.models.catalog_category_create_query import CatalogCategoryCreateQuery
from openapi_client.models.catalog_category_create_query_resource_object import CatalogCategoryCreateQueryResourceObject
from openapi_client.models.catalog_category_create_query_resource_object_attributes import CatalogCategoryCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_category_create_query_resource_object_relationships import CatalogCategoryCreateQueryResourceObjectRelationships
from openapi_client.models.catalog_category_create_query_resource_object_relationships_items import CatalogCategoryCreateQueryResourceObjectRelationshipsItems
from openapi_client.models.catalog_category_delete_job_create_query import CatalogCategoryDeleteJobCreateQuery
from openapi_client.models.catalog_category_delete_job_create_query_resource_object import CatalogCategoryDeleteJobCreateQueryResourceObject
from openapi_client.models.catalog_category_delete_job_create_query_resource_object_attributes import CatalogCategoryDeleteJobCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_category_delete_job_create_query_resource_object_attributes_categories import CatalogCategoryDeleteJobCreateQueryResourceObjectAttributesCategories
from openapi_client.models.catalog_category_delete_job_response_object_resource import CatalogCategoryDeleteJobResponseObjectResource
from openapi_client.models.catalog_category_delete_query_resource_object import CatalogCategoryDeleteQueryResourceObject
from openapi_client.models.catalog_category_enum import CatalogCategoryEnum
from openapi_client.models.catalog_category_item_op import CatalogCategoryItemOp
from openapi_client.models.catalog_category_response_object_resource import CatalogCategoryResponseObjectResource
from openapi_client.models.catalog_category_response_object_resource_attributes import CatalogCategoryResponseObjectResourceAttributes
from openapi_client.models.catalog_category_update_job_create_query import CatalogCategoryUpdateJobCreateQuery
from openapi_client.models.catalog_category_update_job_create_query_resource_object import CatalogCategoryUpdateJobCreateQueryResourceObject
from openapi_client.models.catalog_category_update_job_create_query_resource_object_attributes import CatalogCategoryUpdateJobCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_category_update_job_create_query_resource_object_attributes_categories import CatalogCategoryUpdateJobCreateQueryResourceObjectAttributesCategories
from openapi_client.models.catalog_category_update_job_response_object_resource import CatalogCategoryUpdateJobResponseObjectResource
from openapi_client.models.catalog_category_update_query import CatalogCategoryUpdateQuery
from openapi_client.models.catalog_category_update_query_resource_object import CatalogCategoryUpdateQueryResourceObject
from openapi_client.models.catalog_category_update_query_resource_object_attributes import CatalogCategoryUpdateQueryResourceObjectAttributes
from openapi_client.models.catalog_item_bulk_create_job_enum import CatalogItemBulkCreateJobEnum
from openapi_client.models.catalog_item_bulk_delete_job_enum import CatalogItemBulkDeleteJobEnum
from openapi_client.models.catalog_item_bulk_update_job_enum import CatalogItemBulkUpdateJobEnum
from openapi_client.models.catalog_item_category_op import CatalogItemCategoryOp
from openapi_client.models.catalog_item_create_job_create_query import CatalogItemCreateJobCreateQuery
from openapi_client.models.catalog_item_create_job_create_query_resource_object import CatalogItemCreateJobCreateQueryResourceObject
from openapi_client.models.catalog_item_create_job_create_query_resource_object_attributes import CatalogItemCreateJobCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_item_create_job_create_query_resource_object_attributes_items import CatalogItemCreateJobCreateQueryResourceObjectAttributesItems
from openapi_client.models.catalog_item_create_job_response_object_resource import CatalogItemCreateJobResponseObjectResource
from openapi_client.models.catalog_item_create_query import CatalogItemCreateQuery
from openapi_client.models.catalog_item_create_query_resource_object import CatalogItemCreateQueryResourceObject
from openapi_client.models.catalog_item_create_query_resource_object_attributes import CatalogItemCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_item_create_query_resource_object_relationships import CatalogItemCreateQueryResourceObjectRelationships
from openapi_client.models.catalog_item_create_query_resource_object_relationships_categories import CatalogItemCreateQueryResourceObjectRelationshipsCategories
from openapi_client.models.catalog_item_delete_job_create_query import CatalogItemDeleteJobCreateQuery
from openapi_client.models.catalog_item_delete_job_create_query_resource_object import CatalogItemDeleteJobCreateQueryResourceObject
from openapi_client.models.catalog_item_delete_job_create_query_resource_object_attributes import CatalogItemDeleteJobCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_item_delete_job_create_query_resource_object_attributes_items import CatalogItemDeleteJobCreateQueryResourceObjectAttributesItems
from openapi_client.models.catalog_item_delete_job_response_object_resource import CatalogItemDeleteJobResponseObjectResource
from openapi_client.models.catalog_item_delete_query_resource_object import CatalogItemDeleteQueryResourceObject
from openapi_client.models.catalog_item_enum import CatalogItemEnum
from openapi_client.models.catalog_item_response_object_resource import CatalogItemResponseObjectResource
from openapi_client.models.catalog_item_response_object_resource_attributes import CatalogItemResponseObjectResourceAttributes
from openapi_client.models.catalog_item_update_job_create_query import CatalogItemUpdateJobCreateQuery
from openapi_client.models.catalog_item_update_job_create_query_resource_object import CatalogItemUpdateJobCreateQueryResourceObject
from openapi_client.models.catalog_item_update_job_create_query_resource_object_attributes import CatalogItemUpdateJobCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_item_update_job_create_query_resource_object_attributes_items import CatalogItemUpdateJobCreateQueryResourceObjectAttributesItems
from openapi_client.models.catalog_item_update_job_response_object_resource import CatalogItemUpdateJobResponseObjectResource
from openapi_client.models.catalog_item_update_query import CatalogItemUpdateQuery
from openapi_client.models.catalog_item_update_query_resource_object import CatalogItemUpdateQueryResourceObject
from openapi_client.models.catalog_item_update_query_resource_object_attributes import CatalogItemUpdateQueryResourceObjectAttributes
from openapi_client.models.catalog_variant_bulk_create_job_enum import CatalogVariantBulkCreateJobEnum
from openapi_client.models.catalog_variant_bulk_delete_job_enum import CatalogVariantBulkDeleteJobEnum
from openapi_client.models.catalog_variant_bulk_update_job_enum import CatalogVariantBulkUpdateJobEnum
from openapi_client.models.catalog_variant_create_job_create_query import CatalogVariantCreateJobCreateQuery
from openapi_client.models.catalog_variant_create_job_create_query_resource_object import CatalogVariantCreateJobCreateQueryResourceObject
from openapi_client.models.catalog_variant_create_job_create_query_resource_object_attributes import CatalogVariantCreateJobCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_variant_create_job_create_query_resource_object_attributes_variants import CatalogVariantCreateJobCreateQueryResourceObjectAttributesVariants
from openapi_client.models.catalog_variant_create_job_response_object_resource import CatalogVariantCreateJobResponseObjectResource
from openapi_client.models.catalog_variant_create_query import CatalogVariantCreateQuery
from openapi_client.models.catalog_variant_create_query_resource_object import CatalogVariantCreateQueryResourceObject
from openapi_client.models.catalog_variant_create_query_resource_object_attributes import CatalogVariantCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_variant_create_query_resource_object_relationships import CatalogVariantCreateQueryResourceObjectRelationships
from openapi_client.models.catalog_variant_create_query_resource_object_relationships_item import CatalogVariantCreateQueryResourceObjectRelationshipsItem
from openapi_client.models.catalog_variant_create_query_resource_object_relationships_item_data import CatalogVariantCreateQueryResourceObjectRelationshipsItemData
from openapi_client.models.catalog_variant_delete_job_create_query import CatalogVariantDeleteJobCreateQuery
from openapi_client.models.catalog_variant_delete_job_create_query_resource_object import CatalogVariantDeleteJobCreateQueryResourceObject
from openapi_client.models.catalog_variant_delete_job_create_query_resource_object_attributes import CatalogVariantDeleteJobCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_variant_delete_job_create_query_resource_object_attributes_variants import CatalogVariantDeleteJobCreateQueryResourceObjectAttributesVariants
from openapi_client.models.catalog_variant_delete_job_response_object_resource import CatalogVariantDeleteJobResponseObjectResource
from openapi_client.models.catalog_variant_delete_query_resource_object import CatalogVariantDeleteQueryResourceObject
from openapi_client.models.catalog_variant_enum import CatalogVariantEnum
from openapi_client.models.catalog_variant_response_object_resource import CatalogVariantResponseObjectResource
from openapi_client.models.catalog_variant_response_object_resource_attributes import CatalogVariantResponseObjectResourceAttributes
from openapi_client.models.catalog_variant_update_job_create_query import CatalogVariantUpdateJobCreateQuery
from openapi_client.models.catalog_variant_update_job_create_query_resource_object import CatalogVariantUpdateJobCreateQueryResourceObject
from openapi_client.models.catalog_variant_update_job_create_query_resource_object_attributes import CatalogVariantUpdateJobCreateQueryResourceObjectAttributes
from openapi_client.models.catalog_variant_update_job_create_query_resource_object_attributes_variants import CatalogVariantUpdateJobCreateQueryResourceObjectAttributesVariants
from openapi_client.models.catalog_variant_update_job_response_object_resource import CatalogVariantUpdateJobResponseObjectResource
from openapi_client.models.catalog_variant_update_query import CatalogVariantUpdateQuery
from openapi_client.models.catalog_variant_update_query_resource_object import CatalogVariantUpdateQueryResourceObject
from openapi_client.models.catalog_variant_update_query_resource_object_attributes import CatalogVariantUpdateQueryResourceObjectAttributes
from openapi_client.models.collection_links import CollectionLinks
from openapi_client.models.condition_group import ConditionGroup
from openapi_client.models.contact_information import ContactInformation
from openapi_client.models.coupon_code_bulk_create_job_enum import CouponCodeBulkCreateJobEnum
from openapi_client.models.coupon_code_create_job_create_query import CouponCodeCreateJobCreateQuery
from openapi_client.models.coupon_code_create_job_create_query_resource_object import CouponCodeCreateJobCreateQueryResourceObject
from openapi_client.models.coupon_code_create_job_create_query_resource_object_attributes import CouponCodeCreateJobCreateQueryResourceObjectAttributes
from openapi_client.models.coupon_code_create_job_create_query_resource_object_attributes_coupon_codes import CouponCodeCreateJobCreateQueryResourceObjectAttributesCouponCodes
from openapi_client.models.coupon_code_create_job_response_object_resource import CouponCodeCreateJobResponseObjectResource
from openapi_client.models.coupon_code_create_job_response_object_resource_attributes import CouponCodeCreateJobResponseObjectResourceAttributes
from openapi_client.models.coupon_code_create_query import CouponCodeCreateQuery
from openapi_client.models.coupon_code_create_query_resource_object import CouponCodeCreateQueryResourceObject
from openapi_client.models.coupon_code_create_query_resource_object_attributes import CouponCodeCreateQueryResourceObjectAttributes
from openapi_client.models.coupon_code_create_query_resource_object_relationships import CouponCodeCreateQueryResourceObjectRelationships
from openapi_client.models.coupon_code_create_query_resource_object_relationships_coupon import CouponCodeCreateQueryResourceObjectRelationshipsCoupon
from openapi_client.models.coupon_code_enum import CouponCodeEnum
from openapi_client.models.coupon_code_response_object_resource import CouponCodeResponseObjectResource
from openapi_client.models.coupon_code_response_object_resource_attributes import CouponCodeResponseObjectResourceAttributes
from openapi_client.models.coupon_code_update_query import CouponCodeUpdateQuery
from openapi_client.models.coupon_code_update_query_resource_object import CouponCodeUpdateQueryResourceObject
from openapi_client.models.coupon_code_update_query_resource_object_attributes import CouponCodeUpdateQueryResourceObjectAttributes
from openapi_client.models.coupon_create_query import CouponCreateQuery
from openapi_client.models.coupon_create_query_resource_object import CouponCreateQueryResourceObject
from openapi_client.models.coupon_enum import CouponEnum
from openapi_client.models.coupon_response_object_resource import CouponResponseObjectResource
from openapi_client.models.coupon_response_object_resource_attributes import CouponResponseObjectResourceAttributes
from openapi_client.models.coupon_update_query import CouponUpdateQuery
from openapi_client.models.coupon_update_query_resource_object import CouponUpdateQueryResourceObject
from openapi_client.models.coupon_update_query_resource_object_attributes import CouponUpdateQueryResourceObjectAttributes
from openapi_client.models.custom_tracking_param_dto import CustomTrackingParamDTO
from openapi_client.models.data_privacy_create_deletion_job_query import DataPrivacyCreateDeletionJobQuery
from openapi_client.models.data_privacy_create_deletion_job_query_resource_object import DataPrivacyCreateDeletionJobQueryResourceObject
from openapi_client.models.data_privacy_create_deletion_job_query_resource_object_attributes import DataPrivacyCreateDeletionJobQueryResourceObjectAttributes
from openapi_client.models.data_privacy_create_deletion_job_query_resource_object_attributes_profile import DataPrivacyCreateDeletionJobQueryResourceObjectAttributesProfile
from openapi_client.models.data_privacy_deletion_job_enum import DataPrivacyDeletionJobEnum
from openapi_client.models.data_privacy_profile_query_resource_object import DataPrivacyProfileQueryResourceObject
from openapi_client.models.data_privacy_profile_query_resource_object_attributes import DataPrivacyProfileQueryResourceObjectAttributes
from openapi_client.models.delete_tag_group_response import DeleteTagGroupResponse
from openapi_client.models.device_metadata import DeviceMetadata
from openapi_client.models.email_channel import EmailChannel
from openapi_client.models.email_marketing import EmailMarketing
from openapi_client.models.email_marketing_list_suppression import EmailMarketingListSuppression
from openapi_client.models.email_marketing_suppression import EmailMarketingSuppression
from openapi_client.models.email_subscription_parameters import EmailSubscriptionParameters
from openapi_client.models.error_source import ErrorSource
from openapi_client.models.event_bulk_create_enum import EventBulkCreateEnum
from openapi_client.models.event_bulk_create_job_enum import EventBulkCreateJobEnum
from openapi_client.models.event_create_query_v2 import EventCreateQueryV2
from openapi_client.models.event_create_query_v2_resource_object import EventCreateQueryV2ResourceObject
from openapi_client.models.event_create_query_v2_resource_object_attributes import EventCreateQueryV2ResourceObjectAttributes
from openapi_client.models.event_create_query_v2_resource_object_attributes_metric import EventCreateQueryV2ResourceObjectAttributesMetric
from openapi_client.models.event_create_query_v2_resource_object_attributes_profile import EventCreateQueryV2ResourceObjectAttributesProfile
from openapi_client.models.event_enum import EventEnum
from openapi_client.models.event_profile_create_query_resource_object import EventProfileCreateQueryResourceObject
from openapi_client.models.event_profile_create_query_resource_object_attributes import EventProfileCreateQueryResourceObjectAttributes
from openapi_client.models.event_response_object_resource import EventResponseObjectResource
from openapi_client.models.event_response_object_resource_attributes import EventResponseObjectResourceAttributes
from openapi_client.models.events_bulk_create_job import EventsBulkCreateJob
from openapi_client.models.events_bulk_create_job_resource_object import EventsBulkCreateJobResourceObject
from openapi_client.models.events_bulk_create_job_resource_object_attributes import EventsBulkCreateJobResourceObjectAttributes
from openapi_client.models.events_bulk_create_job_resource_object_attributes_events_bulk_create import EventsBulkCreateJobResourceObjectAttributesEventsBulkCreate
from openapi_client.models.events_bulk_create_query_resource_object import EventsBulkCreateQueryResourceObject
from openapi_client.models.events_bulk_create_query_resource_object_attributes import EventsBulkCreateQueryResourceObjectAttributes
from openapi_client.models.events_bulk_create_query_resource_object_attributes_events import EventsBulkCreateQueryResourceObjectAttributesEvents
from openapi_client.models.events_bulk_create_query_resource_object_attributes_profile import EventsBulkCreateQueryResourceObjectAttributesProfile
from openapi_client.models.flow_action_enum import FlowActionEnum
from openapi_client.models.flow_action_response_object_resource import FlowActionResponseObjectResource
from openapi_client.models.flow_action_response_object_resource_attributes import FlowActionResponseObjectResourceAttributes
from openapi_client.models.flow_enum import FlowEnum
from openapi_client.models.flow_message_enum import FlowMessageEnum
from openapi_client.models.flow_message_response_object_resource import FlowMessageResponseObjectResource
from openapi_client.models.flow_message_response_object_resource_attributes import FlowMessageResponseObjectResourceAttributes
from openapi_client.models.flow_response_object_resource import FlowResponseObjectResource
from openapi_client.models.flow_response_object_resource_attributes import FlowResponseObjectResourceAttributes
from openapi_client.models.flow_series_report_enum import FlowSeriesReportEnum
from openapi_client.models.flow_series_request_dto import FlowSeriesRequestDTO
from openapi_client.models.flow_series_request_dto_resource_object import FlowSeriesRequestDTOResourceObject
from openapi_client.models.flow_series_request_dto_resource_object_attributes import FlowSeriesRequestDTOResourceObjectAttributes
from openapi_client.models.flow_update_query import FlowUpdateQuery
from openapi_client.models.flow_update_query_resource_object import FlowUpdateQueryResourceObject
from openapi_client.models.flow_update_query_resource_object_attributes import FlowUpdateQueryResourceObjectAttributes
from openapi_client.models.flow_values_report_enum import FlowValuesReportEnum
from openapi_client.models.flow_values_request_dto import FlowValuesRequestDTO
from openapi_client.models.flow_values_request_dto_resource_object import FlowValuesRequestDTOResourceObject
from openapi_client.models.flow_values_request_dto_resource_object_attributes import FlowValuesRequestDTOResourceObjectAttributes
from openapi_client.models.form_enum import FormEnum
from openapi_client.models.form_response_object_resource import FormResponseObjectResource
from openapi_client.models.form_response_object_resource_attributes import FormResponseObjectResourceAttributes
from openapi_client.models.form_series_report_enum import FormSeriesReportEnum
from openapi_client.models.form_series_request_dto import FormSeriesRequestDTO
from openapi_client.models.form_series_request_dto_resource_object import FormSeriesRequestDTOResourceObject
from openapi_client.models.form_series_request_dto_resource_object_attributes import FormSeriesRequestDTOResourceObjectAttributes
from openapi_client.models.form_values_report_enum import FormValuesReportEnum
from openapi_client.models.form_values_request_dto import FormValuesRequestDTO
from openapi_client.models.form_values_request_dto_resource_object import FormValuesRequestDTOResourceObject
from openapi_client.models.form_values_request_dto_resource_object_attributes import FormValuesRequestDTOResourceObjectAttributes
from openapi_client.models.form_version_ab_test import FormVersionABTest
from openapi_client.models.form_version_enum import FormVersionEnum
from openapi_client.models.form_version_response_object_resource import FormVersionResponseObjectResource
from openapi_client.models.form_version_response_object_resource_attributes import FormVersionResponseObjectResourceAttributes
from openapi_client.models.get_account_response import GetAccountResponse
from openapi_client.models.get_account_response_collection import GetAccountResponseCollection
from openapi_client.models.get_accounts4_xx_response import GetAccounts4XXResponse
from openapi_client.models.get_accounts4_xx_response_errors_inner import GetAccounts4XXResponseErrorsInner
from openapi_client.models.get_accounts4_xx_response_errors_inner_source import GetAccounts4XXResponseErrorsInnerSource
from openapi_client.models.get_bulk_profile_suppressions_create_job_response import GetBulkProfileSuppressionsCreateJobResponse
from openapi_client.models.get_bulk_profile_suppressions_create_job_response_collection import GetBulkProfileSuppressionsCreateJobResponseCollection
from openapi_client.models.get_bulk_profile_suppressions_create_job_response_collection_data_inner import GetBulkProfileSuppressionsCreateJobResponseCollectionDataInner
from openapi_client.models.get_bulk_profile_suppressions_remove_job_response import GetBulkProfileSuppressionsRemoveJobResponse
from openapi_client.models.get_bulk_profile_suppressions_remove_job_response_collection import GetBulkProfileSuppressionsRemoveJobResponseCollection
from openapi_client.models.get_bulk_profile_suppressions_remove_job_response_collection_data_inner import GetBulkProfileSuppressionsRemoveJobResponseCollectionDataInner
from openapi_client.models.get_campaign_message_campaign_relationship_response import GetCampaignMessageCampaignRelationshipResponse
from openapi_client.models.get_campaign_message_campaign_relationship_response_data import GetCampaignMessageCampaignRelationshipResponseData
from openapi_client.models.get_campaign_message_response_collection_compound_document import GetCampaignMessageResponseCollectionCompoundDocument
from openapi_client.models.get_campaign_message_response_compound_document import GetCampaignMessageResponseCompoundDocument
from openapi_client.models.get_campaign_message_response_compound_document_data import GetCampaignMessageResponseCompoundDocumentData
from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationships
from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_campaign import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsCampaign
from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_campaign_data import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsCampaignData
from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_template import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsTemplate
from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_template_data import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsTemplateData
from openapi_client.models.get_campaign_message_template_relationship_list_response import GetCampaignMessageTemplateRelationshipListResponse
from openapi_client.models.get_campaign_messages_relationship_list_response_collection import GetCampaignMessagesRelationshipListResponseCollection
from openapi_client.models.get_campaign_messages_relationship_list_response_collection_data_inner import GetCampaignMessagesRelationshipListResponseCollectionDataInner
from openapi_client.models.get_campaign_recipient_estimation_job_response import GetCampaignRecipientEstimationJobResponse
from openapi_client.models.get_campaign_recipient_estimation_response import GetCampaignRecipientEstimationResponse
from openapi_client.models.get_campaign_response import GetCampaignResponse
from openapi_client.models.get_campaign_response_collection_compound_document import GetCampaignResponseCollectionCompoundDocument
from openapi_client.models.get_campaign_response_collection_compound_document_data_inner import GetCampaignResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships import GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships_campaign_messages import GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCampaignMessages
from openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships_campaign_messages_data_inner import GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCampaignMessagesDataInner
from openapi_client.models.get_campaign_response_compound_document import GetCampaignResponseCompoundDocument
from openapi_client.models.get_campaign_response_data import GetCampaignResponseData
from openapi_client.models.get_campaign_response_data_all_of_relationships import GetCampaignResponseDataAllOfRelationships
from openapi_client.models.get_campaign_send_job_response import GetCampaignSendJobResponse
from openapi_client.models.get_campaign_tag_relationship_list_response_collection import GetCampaignTagRelationshipListResponseCollection
from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document import GetCatalogCategoryCreateJobResponseCollectionCompoundDocument
from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships_categories import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategories
from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships_categories_data_inner import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategoriesDataInner
from openapi_client.models.get_catalog_category_create_job_response_compound_document import GetCatalogCategoryCreateJobResponseCompoundDocument
from openapi_client.models.get_catalog_category_delete_job_response import GetCatalogCategoryDeleteJobResponse
from openapi_client.models.get_catalog_category_delete_job_response_collection import GetCatalogCategoryDeleteJobResponseCollection
from openapi_client.models.get_catalog_category_delete_job_response_collection_data_inner import GetCatalogCategoryDeleteJobResponseCollectionDataInner
from openapi_client.models.get_catalog_category_delete_job_response_collection_data_inner_all_of_relationships import GetCatalogCategoryDeleteJobResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_catalog_category_item_list_response_collection import GetCatalogCategoryItemListResponseCollection
from openapi_client.models.get_catalog_category_item_list_response_collection_data_inner import GetCatalogCategoryItemListResponseCollectionDataInner
from openapi_client.models.get_catalog_category_response import GetCatalogCategoryResponse
from openapi_client.models.get_catalog_category_response_collection import GetCatalogCategoryResponseCollection
from openapi_client.models.get_catalog_category_response_collection_data_inner import GetCatalogCategoryResponseCollectionDataInner
from openapi_client.models.get_catalog_category_response_collection_data_inner_all_of_relationships import GetCatalogCategoryResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocument
from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships_categories import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategories
from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships_categories_data_inner import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategoriesDataInner
from openapi_client.models.get_catalog_category_update_job_response_compound_document import GetCatalogCategoryUpdateJobResponseCompoundDocument
from openapi_client.models.get_catalog_item_category_list_response_collection import GetCatalogItemCategoryListResponseCollection
from openapi_client.models.get_catalog_item_category_list_response_collection_data_inner import GetCatalogItemCategoryListResponseCollectionDataInner
from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document import GetCatalogItemCreateJobResponseCollectionCompoundDocument
from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships_items import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItems
from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships_items_data_inner import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItemsDataInner
from openapi_client.models.get_catalog_item_create_job_response_compound_document import GetCatalogItemCreateJobResponseCompoundDocument
from openapi_client.models.get_catalog_item_delete_job_response import GetCatalogItemDeleteJobResponse
from openapi_client.models.get_catalog_item_delete_job_response_collection import GetCatalogItemDeleteJobResponseCollection
from openapi_client.models.get_catalog_item_delete_job_response_collection_data_inner import GetCatalogItemDeleteJobResponseCollectionDataInner
from openapi_client.models.get_catalog_item_response_collection_compound_document import GetCatalogItemResponseCollectionCompoundDocument
from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner import GetCatalogItemResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships_variants import GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants
from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner import GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner
from openapi_client.models.get_catalog_item_response_compound_document import GetCatalogItemResponseCompoundDocument
from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document import GetCatalogItemUpdateJobResponseCollectionCompoundDocument
from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships_items import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItems
from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships_items_data_inner import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItemsDataInner
from openapi_client.models.get_catalog_item_update_job_response_compound_document import GetCatalogItemUpdateJobResponseCompoundDocument
from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document import GetCatalogVariantCreateJobResponseCollectionCompoundDocument
from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships_variants import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants
from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner
from openapi_client.models.get_catalog_variant_create_job_response_compound_document import GetCatalogVariantCreateJobResponseCompoundDocument
from openapi_client.models.get_catalog_variant_delete_job_response import GetCatalogVariantDeleteJobResponse
from openapi_client.models.get_catalog_variant_delete_job_response_collection import GetCatalogVariantDeleteJobResponseCollection
from openapi_client.models.get_catalog_variant_delete_job_response_collection_data_inner import GetCatalogVariantDeleteJobResponseCollectionDataInner
from openapi_client.models.get_catalog_variant_delete_job_response_collection_data_inner_all_of_relationships import GetCatalogVariantDeleteJobResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_catalog_variant_response import GetCatalogVariantResponse
from openapi_client.models.get_catalog_variant_response_collection import GetCatalogVariantResponseCollection
from openapi_client.models.get_catalog_variant_response_collection_data_inner import GetCatalogVariantResponseCollectionDataInner
from openapi_client.models.get_catalog_variant_response_collection_data_inner_all_of_relationships import GetCatalogVariantResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document import GetCatalogVariantUpdateJobResponseCollectionCompoundDocument
from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships_variants import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants
from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner
from openapi_client.models.get_catalog_variant_update_job_response_compound_document import GetCatalogVariantUpdateJobResponseCompoundDocument
from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document import GetCouponCodeCreateJobResponseCollectionCompoundDocument
from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships_coupon_codes import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponCodes
from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships_coupon_codes_data_inner import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponCodesDataInner
from openapi_client.models.get_coupon_code_create_job_response_compound_document import GetCouponCodeCreateJobResponseCompoundDocument
from openapi_client.models.get_coupon_code_relationship_coupon_response import GetCouponCodeRelationshipCouponResponse
from openapi_client.models.get_coupon_code_relationship_coupon_response_data import GetCouponCodeRelationshipCouponResponseData
from openapi_client.models.get_coupon_code_response_collection import GetCouponCodeResponseCollection
from openapi_client.models.get_coupon_code_response_collection_compound_document import GetCouponCodeResponseCollectionCompoundDocument
from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner import GetCouponCodeResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_coupon import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCoupon
from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_coupon_data import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponData
from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_profile import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfile
from openapi_client.models.get_coupon_code_response_collection_data_inner import GetCouponCodeResponseCollectionDataInner
from openapi_client.models.get_coupon_code_response_collection_data_inner_all_of_relationships import GetCouponCodeResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_coupon_code_response_compound_document import GetCouponCodeResponseCompoundDocument
from openapi_client.models.get_coupon_relationship_coupon_codes_list_response_collection import GetCouponRelationshipCouponCodesListResponseCollection
from openapi_client.models.get_coupon_relationship_coupon_codes_list_response_collection_data_inner import GetCouponRelationshipCouponCodesListResponseCollectionDataInner
from openapi_client.models.get_coupon_response import GetCouponResponse
from openapi_client.models.get_coupon_response_collection import GetCouponResponseCollection
from openapi_client.models.get_event_metric_relationship_response import GetEventMetricRelationshipResponse
from openapi_client.models.get_event_metric_relationship_response_data import GetEventMetricRelationshipResponseData
from openapi_client.models.get_event_profile_relationship_response import GetEventProfileRelationshipResponse
from openapi_client.models.get_event_profile_relationship_response_data import GetEventProfileRelationshipResponseData
from openapi_client.models.get_event_response_collection_compound_document import GetEventResponseCollectionCompoundDocument
from openapi_client.models.get_event_response_collection_compound_document_data_inner import GetEventResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_attributions import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsAttributions
from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_attributions_data_inner import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsAttributionsDataInner
from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_metric import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetric
from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_metric_data import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetricData
from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_profile import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfile
from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_profile_data import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfileData
from openapi_client.models.get_event_response_compound_document import GetEventResponseCompoundDocument
from openapi_client.models.get_flow_action_flow_message_relationship_response_collection import GetFlowActionFlowMessageRelationshipResponseCollection
from openapi_client.models.get_flow_action_flow_relationship_response import GetFlowActionFlowRelationshipResponse
from openapi_client.models.get_flow_action_response import GetFlowActionResponse
from openapi_client.models.get_flow_action_response_collection import GetFlowActionResponseCollection
from openapi_client.models.get_flow_action_response_collection_data_inner import GetFlowActionResponseCollectionDataInner
from openapi_client.models.get_flow_action_response_collection_data_inner_all_of_relationships import GetFlowActionResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_flow_action_response_compound_document import GetFlowActionResponseCompoundDocument
from openapi_client.models.get_flow_action_response_compound_document_data import GetFlowActionResponseCompoundDocumentData
from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships import GetFlowActionResponseCompoundDocumentDataAllOfRelationships
from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow import GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlow
from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow_messages import GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlowMessages
from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow_messages_data_inner import GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlowMessagesDataInner
from openapi_client.models.get_flow_flow_action_relationship_list_response_collection import GetFlowFlowActionRelationshipListResponseCollection
from openapi_client.models.get_flow_message_flow_action_relationship_response import GetFlowMessageFlowActionRelationshipResponse
from openapi_client.models.get_flow_message_response_collection import GetFlowMessageResponseCollection
from openapi_client.models.get_flow_message_response_collection_data_inner import GetFlowMessageResponseCollectionDataInner
from openapi_client.models.get_flow_message_response_collection_data_inner_all_of_relationships import GetFlowMessageResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_flow_message_response_compound_document import GetFlowMessageResponseCompoundDocument
from openapi_client.models.get_flow_message_response_compound_document_data import GetFlowMessageResponseCompoundDocumentData
from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships import GetFlowMessageResponseCompoundDocumentDataAllOfRelationships
from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_flow_action import GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsFlowAction
from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_template import GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsTemplate
from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_template_data import GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsTemplateData
from openapi_client.models.get_flow_message_template_relationship_response import GetFlowMessageTemplateRelationshipResponse
from openapi_client.models.get_flow_response import GetFlowResponse
from openapi_client.models.get_flow_response_collection import GetFlowResponseCollection
from openapi_client.models.get_flow_response_collection_compound_document import GetFlowResponseCollectionCompoundDocument
from openapi_client.models.get_flow_response_collection_compound_document_data_inner import GetFlowResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships import GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships_flow_actions import GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowActions
from openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships_flow_actions_data_inner import GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowActionsDataInner
from openapi_client.models.get_flow_response_collection_data_inner import GetFlowResponseCollectionDataInner
from openapi_client.models.get_flow_response_collection_data_inner_all_of_relationships import GetFlowResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_flow_response_compound_document import GetFlowResponseCompoundDocument
from openapi_client.models.get_flow_tag_relationship_list_response_collection import GetFlowTagRelationshipListResponseCollection
from openapi_client.models.get_form_form_version_relationships_response_collection import GetFormFormVersionRelationshipsResponseCollection
from openapi_client.models.get_form_response import GetFormResponse
from openapi_client.models.get_form_response_collection_compound_document import GetFormResponseCollectionCompoundDocument
from openapi_client.models.get_form_response_collection_compound_document_data_inner import GetFormResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_form_response_collection_compound_document_data_inner_all_of_relationships import GetFormResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_form_response_compound_document import GetFormResponseCompoundDocument
from openapi_client.models.get_form_response_compound_document_data import GetFormResponseCompoundDocumentData
from openapi_client.models.get_form_response_compound_document_data_all_of_relationships import GetFormResponseCompoundDocumentDataAllOfRelationships
from openapi_client.models.get_form_response_compound_document_data_all_of_relationships_form_versions import GetFormResponseCompoundDocumentDataAllOfRelationshipsFormVersions
from openapi_client.models.get_form_response_compound_document_data_all_of_relationships_form_versions_data_inner import GetFormResponseCompoundDocumentDataAllOfRelationshipsFormVersionsDataInner
from openapi_client.models.get_form_version_form_relationship_response import GetFormVersionFormRelationshipResponse
from openapi_client.models.get_form_version_form_relationship_response_data import GetFormVersionFormRelationshipResponseData
from openapi_client.models.get_form_version_response import GetFormVersionResponse
from openapi_client.models.get_form_version_response_collection import GetFormVersionResponseCollection
from openapi_client.models.get_image_response import GetImageResponse
from openapi_client.models.get_image_response_collection import GetImageResponseCollection
from openapi_client.models.get_import_error_response_collection import GetImportErrorResponseCollection
from openapi_client.models.get_list_flow_triggers_relationship_response_collection import GetListFlowTriggersRelationshipResponseCollection
from openapi_client.models.get_list_list_response_collection_compound_document import GetListListResponseCollectionCompoundDocument
from openapi_client.models.get_list_list_response_collection_compound_document_data_inner import GetListListResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships import GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships_tags import GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTags
from openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships_tags_data_inner import GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagsDataInner
from openapi_client.models.get_list_member_response_collection import GetListMemberResponseCollection
from openapi_client.models.get_list_member_response_collection_data_inner import GetListMemberResponseCollectionDataInner
from openapi_client.models.get_list_relationships_response_collection import GetListRelationshipsResponseCollection
from openapi_client.models.get_list_response_collection import GetListResponseCollection
from openapi_client.models.get_list_response_collection_data_inner import GetListResponseCollectionDataInner
from openapi_client.models.get_list_response_collection_data_inner_all_of_relationships import GetListResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_list_retrieve_response_compound_document import GetListRetrieveResponseCompoundDocument
from openapi_client.models.get_list_retrieve_response_compound_document_data import GetListRetrieveResponseCompoundDocumentData
from openapi_client.models.get_list_tag_relationship_list_response_collection import GetListTagRelationshipListResponseCollection
from openapi_client.models.get_metric_flow_triggers_relationship_response_collection import GetMetricFlowTriggersRelationshipResponseCollection
from openapi_client.models.get_metric_flow_triggers_relationship_response_collection_data_inner import GetMetricFlowTriggersRelationshipResponseCollectionDataInner
from openapi_client.models.get_metric_property_relationship_metric_response import GetMetricPropertyRelationshipMetricResponse
from openapi_client.models.get_metric_property_relationship_metric_response_data import GetMetricPropertyRelationshipMetricResponseData
from openapi_client.models.get_metric_property_response_collection import GetMetricPropertyResponseCollection
from openapi_client.models.get_metric_property_response_collection_data_inner import GetMetricPropertyResponseCollectionDataInner
from openapi_client.models.get_metric_property_response_collection_data_inner_all_of_relationships import GetMetricPropertyResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_metric_property_response_compound_document import GetMetricPropertyResponseCompoundDocument
from openapi_client.models.get_metric_property_response_compound_document_data import GetMetricPropertyResponseCompoundDocumentData
from openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships import GetMetricPropertyResponseCompoundDocumentDataAllOfRelationships
from openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships_metric import GetMetricPropertyResponseCompoundDocumentDataAllOfRelationshipsMetric
from openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships_metric_data import GetMetricPropertyResponseCompoundDocumentDataAllOfRelationshipsMetricData
from openapi_client.models.get_metric_relationship_metric_property_response_collection import GetMetricRelationshipMetricPropertyResponseCollection
from openapi_client.models.get_metric_relationship_metric_property_response_collection_data_inner import GetMetricRelationshipMetricPropertyResponseCollectionDataInner
from openapi_client.models.get_metric_response import GetMetricResponse
from openapi_client.models.get_metric_response_collection_compound_document import GetMetricResponseCollectionCompoundDocument
from openapi_client.models.get_metric_response_compound_document import GetMetricResponseCompoundDocument
from openapi_client.models.get_metric_response_data import GetMetricResponseData
from openapi_client.models.get_metric_response_data_all_of_relationships import GetMetricResponseDataAllOfRelationships
from openapi_client.models.get_profile_import_job_list_relationships_response_collection import GetProfileImportJobListRelationshipsResponseCollection
from openapi_client.models.get_profile_import_job_profile_relationships_response_collection import GetProfileImportJobProfileRelationshipsResponseCollection
from openapi_client.models.get_profile_import_job_response_collection_compound_document import GetProfileImportJobResponseCollectionCompoundDocument
from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner import GetProfileImportJobResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_import_errors import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsImportErrors
from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_lists import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsLists
from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_lists_data_inner import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsListsDataInner
from openapi_client.models.get_profile_import_job_response_compound_document import GetProfileImportJobResponseCompoundDocument
from openapi_client.models.get_profile_list_relationships_response_collection import GetProfileListRelationshipsResponseCollection
from openapi_client.models.get_profile_response import GetProfileResponse
from openapi_client.models.get_profile_response_collection import GetProfileResponseCollection
from openapi_client.models.get_profile_response_collection_compound_document import GetProfileResponseCollectionCompoundDocument
from openapi_client.models.get_profile_response_compound_document import GetProfileResponseCompoundDocument
from openapi_client.models.get_profile_response_compound_document_data import GetProfileResponseCompoundDocumentData
from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships import GetProfileResponseCompoundDocumentDataAllOfRelationships
from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_lists import GetProfileResponseCompoundDocumentDataAllOfRelationshipsLists
from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_lists_data_inner import GetProfileResponseCompoundDocumentDataAllOfRelationshipsListsDataInner
from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_segments import GetProfileResponseCompoundDocumentDataAllOfRelationshipsSegments
from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_segments_data_inner import GetProfileResponseCompoundDocumentDataAllOfRelationshipsSegmentsDataInner
from openapi_client.models.get_profile_response_data import GetProfileResponseData
from openapi_client.models.get_profile_response_data_all_of_relationships import GetProfileResponseDataAllOfRelationships
from openapi_client.models.get_profile_segment_relationships_response_collection import GetProfileSegmentRelationshipsResponseCollection
from openapi_client.models.get_review_response_dto20240715_collection_compound_document import GetReviewResponseDTO20240715CollectionCompoundDocument
from openapi_client.models.get_review_response_dto20240715_collection_compound_document_data_inner import GetReviewResponseDTO20240715CollectionCompoundDocumentDataInner
from openapi_client.models.get_review_response_dto20240715_collection_compound_document_data_inner_all_of_relationships import GetReviewResponseDTO20240715CollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_review_response_dto20240715_collection_compound_document_data_inner_all_of_relationships_events import GetReviewResponseDTO20240715CollectionCompoundDocumentDataInnerAllOfRelationshipsEvents
from openapi_client.models.get_review_response_dto20240715_collection_compound_document_data_inner_all_of_relationships_events_data_inner import GetReviewResponseDTO20240715CollectionCompoundDocumentDataInnerAllOfRelationshipsEventsDataInner
from openapi_client.models.get_review_response_dto20240715_compound_document import GetReviewResponseDTO20240715CompoundDocument
from openapi_client.models.get_segment_flow_triggers_relationships_response_collection import GetSegmentFlowTriggersRelationshipsResponseCollection
from openapi_client.models.get_segment_list_response_collection_compound_document import GetSegmentListResponseCollectionCompoundDocument
from openapi_client.models.get_segment_list_response_collection_compound_document_data_inner import GetSegmentListResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_segment_member_response_collection import GetSegmentMemberResponseCollection
from openapi_client.models.get_segment_member_response_collection_data_inner import GetSegmentMemberResponseCollectionDataInner
from openapi_client.models.get_segment_relationships_response_collection import GetSegmentRelationshipsResponseCollection
from openapi_client.models.get_segment_response_collection import GetSegmentResponseCollection
from openapi_client.models.get_segment_response_collection_data_inner import GetSegmentResponseCollectionDataInner
from openapi_client.models.get_segment_retrieve_response_compound_document import GetSegmentRetrieveResponseCompoundDocument
from openapi_client.models.get_segment_retrieve_response_compound_document_data import GetSegmentRetrieveResponseCompoundDocumentData
from openapi_client.models.get_segment_tag_relationship_list_response_collection import GetSegmentTagRelationshipListResponseCollection
from openapi_client.models.get_tag_campaign_relationships_response_collection import GetTagCampaignRelationshipsResponseCollection
from openapi_client.models.get_tag_campaign_relationships_response_collection_data_inner import GetTagCampaignRelationshipsResponseCollectionDataInner
from openapi_client.models.get_tag_flow_relationships_response_collection import GetTagFlowRelationshipsResponseCollection
from openapi_client.models.get_tag_flow_relationships_response_collection_data_inner import GetTagFlowRelationshipsResponseCollectionDataInner
from openapi_client.models.get_tag_group_response import GetTagGroupResponse
from openapi_client.models.get_tag_group_response_collection import GetTagGroupResponseCollection
from openapi_client.models.get_tag_group_response_collection_data_inner import GetTagGroupResponseCollectionDataInner
from openapi_client.models.get_tag_group_response_collection_data_inner_all_of_relationships import GetTagGroupResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_tag_group_tag_relationships_response_collection import GetTagGroupTagRelationshipsResponseCollection
from openapi_client.models.get_tag_group_tag_relationships_response_collection_data_inner import GetTagGroupTagRelationshipsResponseCollectionDataInner
from openapi_client.models.get_tag_list_relationships_response_collection import GetTagListRelationshipsResponseCollection
from openapi_client.models.get_tag_list_relationships_response_collection_data_inner import GetTagListRelationshipsResponseCollectionDataInner
from openapi_client.models.get_tag_response_collection import GetTagResponseCollection
from openapi_client.models.get_tag_response_collection_compound_document import GetTagResponseCollectionCompoundDocument
from openapi_client.models.get_tag_response_collection_compound_document_data_inner import GetTagResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships import GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships_tag_group import GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagGroup
from openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships_tag_group_data import GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagGroupData
from openapi_client.models.get_tag_response_collection_data_inner import GetTagResponseCollectionDataInner
from openapi_client.models.get_tag_response_collection_data_inner_all_of_relationships import GetTagResponseCollectionDataInnerAllOfRelationships
from openapi_client.models.get_tag_response_compound_document import GetTagResponseCompoundDocument
from openapi_client.models.get_tag_segment_relationships_response_collection import GetTagSegmentRelationshipsResponseCollection
from openapi_client.models.get_tag_segment_relationships_response_collection_data_inner import GetTagSegmentRelationshipsResponseCollectionDataInner
from openapi_client.models.get_tag_tag_group_relationships_response import GetTagTagGroupRelationshipsResponse
from openapi_client.models.get_tag_tag_group_relationships_response_data import GetTagTagGroupRelationshipsResponseData
from openapi_client.models.get_template_response import GetTemplateResponse
from openapi_client.models.get_template_response_collection import GetTemplateResponseCollection
from openapi_client.models.get_tracking_setting_response import GetTrackingSettingResponse
from openapi_client.models.get_tracking_setting_response_collection import GetTrackingSettingResponseCollection
from openapi_client.models.get_universal_content_response import GetUniversalContentResponse
from openapi_client.models.get_universal_content_response_collection import GetUniversalContentResponseCollection
from openapi_client.models.get_webhook_response_collection_compound_document import GetWebhookResponseCollectionCompoundDocument
from openapi_client.models.get_webhook_response_collection_compound_document_data_inner import GetWebhookResponseCollectionCompoundDocumentDataInner
from openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships import GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationships
from openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships_webhook_topics import GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsWebhookTopics
from openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships_webhook_topics_data_inner import GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsWebhookTopicsDataInner
from openapi_client.models.get_webhook_response_compound_document import GetWebhookResponseCompoundDocument
from openapi_client.models.get_webhook_topic_response import GetWebhookTopicResponse
from openapi_client.models.get_webhook_topic_response_collection import GetWebhookTopicResponseCollection
from openapi_client.models.image_create_query import ImageCreateQuery
from openapi_client.models.image_create_query_resource_object import ImageCreateQueryResourceObject
from openapi_client.models.image_create_query_resource_object_attributes import ImageCreateQueryResourceObjectAttributes
from openapi_client.models.image_enum import ImageEnum
from openapi_client.models.image_partial_update_query import ImagePartialUpdateQuery
from openapi_client.models.image_partial_update_query_resource_object import ImagePartialUpdateQueryResourceObject
from openapi_client.models.image_partial_update_query_resource_object_attributes import ImagePartialUpdateQueryResourceObjectAttributes
from openapi_client.models.image_response_object_resource import ImageResponseObjectResource
from openapi_client.models.image_response_object_resource_attributes import ImageResponseObjectResourceAttributes
from openapi_client.models.import_error_enum import ImportErrorEnum
from openapi_client.models.import_error_response_object_resource import ImportErrorResponseObjectResource
from openapi_client.models.import_error_response_object_resource_attributes import ImportErrorResponseObjectResourceAttributes
from openapi_client.models.list_create_query import ListCreateQuery
from openapi_client.models.list_create_query_resource_object import ListCreateQueryResourceObject
from openapi_client.models.list_create_query_resource_object_attributes import ListCreateQueryResourceObjectAttributes
from openapi_client.models.list_enum import ListEnum
from openapi_client.models.list_list_response_object_resource import ListListResponseObjectResource
from openapi_client.models.list_list_response_object_resource_attributes import ListListResponseObjectResourceAttributes
from openapi_client.models.list_member_response_object_resource_attributes import ListMemberResponseObjectResourceAttributes
from openapi_client.models.list_member_response_object_resource_extended import ListMemberResponseObjectResourceExtended
from openapi_client.models.list_member_response_object_resource_extended_attributes import ListMemberResponseObjectResourceExtendedAttributes
from openapi_client.models.list_members_add_query import ListMembersAddQuery
from openapi_client.models.list_members_delete_query import ListMembersDeleteQuery
from openapi_client.models.list_partial_update_query import ListPartialUpdateQuery
from openapi_client.models.list_partial_update_query_resource_object import ListPartialUpdateQueryResourceObject
from openapi_client.models.list_response_object_resource import ListResponseObjectResource
from openapi_client.models.list_retrieve_response_object_resource_attributes import ListRetrieveResponseObjectResourceAttributes
from openapi_client.models.list_retrieve_response_object_resource_extended import ListRetrieveResponseObjectResourceExtended
from openapi_client.models.list_retrieve_response_object_resource_extended_attributes import ListRetrieveResponseObjectResourceExtendedAttributes
from openapi_client.models.metric_aggregate_enum import MetricAggregateEnum
from openapi_client.models.metric_aggregate_query import MetricAggregateQuery
from openapi_client.models.metric_aggregate_query_resource_object import MetricAggregateQueryResourceObject
from openapi_client.models.metric_aggregate_query_resource_object_attributes import MetricAggregateQueryResourceObjectAttributes
from openapi_client.models.metric_aggregate_row_dto import MetricAggregateRowDTO
from openapi_client.models.metric_create_query_resource_object import MetricCreateQueryResourceObject
from openapi_client.models.metric_create_query_resource_object_attributes import MetricCreateQueryResourceObjectAttributes
from openapi_client.models.metric_enum import MetricEnum
from openapi_client.models.metric_property_enum import MetricPropertyEnum
from openapi_client.models.metric_property_response_object_resource_attributes import MetricPropertyResponseObjectResourceAttributes
from openapi_client.models.metric_property_response_object_resource_extended import MetricPropertyResponseObjectResourceExtended
from openapi_client.models.metric_property_response_object_resource_extended_attributes import MetricPropertyResponseObjectResourceExtendedAttributes
from openapi_client.models.metric_response_object_resource import MetricResponseObjectResource
from openapi_client.models.metric_response_object_resource_attributes import MetricResponseObjectResourceAttributes
from openapi_client.models.object_links import ObjectLinks
from openapi_client.models.only_related_links import OnlyRelatedLinks
from openapi_client.models.onsite_profile_create_query_resource_object import OnsiteProfileCreateQueryResourceObject
from openapi_client.models.onsite_profile_create_query_resource_object_attributes import OnsiteProfileCreateQueryResourceObjectAttributes
from openapi_client.models.onsite_profile_meta import OnsiteProfileMeta
from openapi_client.models.patch_campaign_message_response import PatchCampaignMessageResponse
from openapi_client.models.patch_campaign_response import PatchCampaignResponse
from openapi_client.models.patch_catalog_category_response import PatchCatalogCategoryResponse
from openapi_client.models.patch_catalog_item_response import PatchCatalogItemResponse
from openapi_client.models.patch_catalog_variant_response import PatchCatalogVariantResponse
from openapi_client.models.patch_coupon_code_response import PatchCouponCodeResponse
from openapi_client.models.patch_coupon_response import PatchCouponResponse
from openapi_client.models.patch_flow_response import PatchFlowResponse
from openapi_client.models.patch_flow_response_data import PatchFlowResponseData
from openapi_client.models.patch_image_response import PatchImageResponse
from openapi_client.models.patch_list_partial_update_response import PatchListPartialUpdateResponse
from openapi_client.models.patch_profile_response import PatchProfileResponse
from openapi_client.models.patch_segment_partial_update_response import PatchSegmentPartialUpdateResponse
from openapi_client.models.patch_tag_group_response import PatchTagGroupResponse
from openapi_client.models.patch_template_response import PatchTemplateResponse
from openapi_client.models.patch_tracking_setting_response import PatchTrackingSettingResponse
from openapi_client.models.patch_tracking_setting_response_data import PatchTrackingSettingResponseData
from openapi_client.models.patch_universal_content_response import PatchUniversalContentResponse
from openapi_client.models.patch_webhook_response import PatchWebhookResponse
from openapi_client.models.post_bulk_profile_suppressions_create_job_response import PostBulkProfileSuppressionsCreateJobResponse
from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data import PostBulkProfileSuppressionsCreateJobResponseData
from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_attributes import PostBulkProfileSuppressionsCreateJobResponseDataAttributes
from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships import PostBulkProfileSuppressionsCreateJobResponseDataRelationships
from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_lists import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsLists
from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_lists_data_inner import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsListsDataInner
from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_segments import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsSegments
from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_segments_data_inner import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsSegmentsDataInner
from openapi_client.models.post_bulk_profile_suppressions_remove_job_response import PostBulkProfileSuppressionsRemoveJobResponse
from openapi_client.models.post_bulk_profile_suppressions_remove_job_response_data import PostBulkProfileSuppressionsRemoveJobResponseData
from openapi_client.models.post_campaign_message_response import PostCampaignMessageResponse
from openapi_client.models.post_campaign_message_response_data import PostCampaignMessageResponseData
from openapi_client.models.post_campaign_message_response_data_attributes import PostCampaignMessageResponseDataAttributes
from openapi_client.models.post_campaign_recipient_estimation_job_response import PostCampaignRecipientEstimationJobResponse
from openapi_client.models.post_campaign_recipient_estimation_job_response_data import PostCampaignRecipientEstimationJobResponseData
from openapi_client.models.post_campaign_recipient_estimation_job_response_data_attributes import PostCampaignRecipientEstimationJobResponseDataAttributes
from openapi_client.models.post_campaign_response import PostCampaignResponse
from openapi_client.models.post_campaign_response_data import PostCampaignResponseData
from openapi_client.models.post_campaign_response_data_attributes import PostCampaignResponseDataAttributes
from openapi_client.models.post_campaign_send_job_response import PostCampaignSendJobResponse
from openapi_client.models.post_campaign_send_job_response_data import PostCampaignSendJobResponseData
from openapi_client.models.post_campaign_send_job_response_data_attributes import PostCampaignSendJobResponseDataAttributes
from openapi_client.models.post_campaign_values_response_dto import PostCampaignValuesResponseDTO
from openapi_client.models.post_campaign_values_response_dto_data import PostCampaignValuesResponseDTOData
from openapi_client.models.post_campaign_values_response_dto_data_attributes import PostCampaignValuesResponseDTODataAttributes
from openapi_client.models.post_campaign_values_response_dto_data_relationships import PostCampaignValuesResponseDTODataRelationships
from openapi_client.models.post_catalog_category_create_job_response import PostCatalogCategoryCreateJobResponse
from openapi_client.models.post_catalog_category_create_job_response_data import PostCatalogCategoryCreateJobResponseData
from openapi_client.models.post_catalog_category_delete_job_response import PostCatalogCategoryDeleteJobResponse
from openapi_client.models.post_catalog_category_delete_job_response_data import PostCatalogCategoryDeleteJobResponseData
from openapi_client.models.post_catalog_category_delete_job_response_data_relationships import PostCatalogCategoryDeleteJobResponseDataRelationships
from openapi_client.models.post_catalog_category_delete_job_response_data_relationships_categories import PostCatalogCategoryDeleteJobResponseDataRelationshipsCategories
from openapi_client.models.post_catalog_category_delete_job_response_data_relationships_categories_data_inner import PostCatalogCategoryDeleteJobResponseDataRelationshipsCategoriesDataInner
from openapi_client.models.post_catalog_category_response import PostCatalogCategoryResponse
from openapi_client.models.post_catalog_category_response_data import PostCatalogCategoryResponseData
from openapi_client.models.post_catalog_category_response_data_relationships import PostCatalogCategoryResponseDataRelationships
from openapi_client.models.post_catalog_category_response_data_relationships_items import PostCatalogCategoryResponseDataRelationshipsItems
from openapi_client.models.post_catalog_category_update_job_response import PostCatalogCategoryUpdateJobResponse
from openapi_client.models.post_catalog_category_update_job_response_data import PostCatalogCategoryUpdateJobResponseData
from openapi_client.models.post_catalog_item_create_job_response import PostCatalogItemCreateJobResponse
from openapi_client.models.post_catalog_item_create_job_response_data import PostCatalogItemCreateJobResponseData
from openapi_client.models.post_catalog_item_delete_job_response import PostCatalogItemDeleteJobResponse
from openapi_client.models.post_catalog_item_delete_job_response_data import PostCatalogItemDeleteJobResponseData
from openapi_client.models.post_catalog_item_delete_job_response_data_relationships import PostCatalogItemDeleteJobResponseDataRelationships
from openapi_client.models.post_catalog_item_delete_job_response_data_relationships_items import PostCatalogItemDeleteJobResponseDataRelationshipsItems
from openapi_client.models.post_catalog_item_delete_job_response_data_relationships_items_data_inner import PostCatalogItemDeleteJobResponseDataRelationshipsItemsDataInner
from openapi_client.models.post_catalog_item_response import PostCatalogItemResponse
from openapi_client.models.post_catalog_item_response_data import PostCatalogItemResponseData
from openapi_client.models.post_catalog_item_update_job_response import PostCatalogItemUpdateJobResponse
from openapi_client.models.post_catalog_item_update_job_response_data import PostCatalogItemUpdateJobResponseData
from openapi_client.models.post_catalog_variant_create_job_response import PostCatalogVariantCreateJobResponse
from openapi_client.models.post_catalog_variant_create_job_response_data import PostCatalogVariantCreateJobResponseData
from openapi_client.models.post_catalog_variant_delete_job_response import PostCatalogVariantDeleteJobResponse
from openapi_client.models.post_catalog_variant_delete_job_response_data import PostCatalogVariantDeleteJobResponseData
from openapi_client.models.post_catalog_variant_delete_job_response_data_relationships import PostCatalogVariantDeleteJobResponseDataRelationships
from openapi_client.models.post_catalog_variant_delete_job_response_data_relationships_variants import PostCatalogVariantDeleteJobResponseDataRelationshipsVariants
from openapi_client.models.post_catalog_variant_delete_job_response_data_relationships_variants_data_inner import PostCatalogVariantDeleteJobResponseDataRelationshipsVariantsDataInner
from openapi_client.models.post_catalog_variant_response import PostCatalogVariantResponse
from openapi_client.models.post_catalog_variant_response_data import PostCatalogVariantResponseData
from openapi_client.models.post_catalog_variant_response_data_relationships import PostCatalogVariantResponseDataRelationships
from openapi_client.models.post_catalog_variant_response_data_relationships_item import PostCatalogVariantResponseDataRelationshipsItem
from openapi_client.models.post_catalog_variant_response_data_relationships_item_data import PostCatalogVariantResponseDataRelationshipsItemData
from openapi_client.models.post_catalog_variant_update_job_response import PostCatalogVariantUpdateJobResponse
from openapi_client.models.post_catalog_variant_update_job_response_data import PostCatalogVariantUpdateJobResponseData
from openapi_client.models.post_coupon_code_create_job_response import PostCouponCodeCreateJobResponse
from openapi_client.models.post_coupon_code_create_job_response_data import PostCouponCodeCreateJobResponseData
from openapi_client.models.post_coupon_code_create_job_response_data_attributes import PostCouponCodeCreateJobResponseDataAttributes
from openapi_client.models.post_coupon_code_response import PostCouponCodeResponse
from openapi_client.models.post_coupon_code_response_data import PostCouponCodeResponseData
from openapi_client.models.post_coupon_code_response_data_relationships import PostCouponCodeResponseDataRelationships
from openapi_client.models.post_coupon_code_response_data_relationships_profile import PostCouponCodeResponseDataRelationshipsProfile
from openapi_client.models.post_coupon_code_response_data_relationships_profile_data import PostCouponCodeResponseDataRelationshipsProfileData
from openapi_client.models.post_coupon_response import PostCouponResponse
from openapi_client.models.post_coupon_response_data import PostCouponResponseData
from openapi_client.models.post_coupon_response_data_attributes import PostCouponResponseDataAttributes
from openapi_client.models.post_flow_series_response_dto import PostFlowSeriesResponseDTO
from openapi_client.models.post_flow_series_response_dto_data import PostFlowSeriesResponseDTOData
from openapi_client.models.post_flow_series_response_dto_data_attributes import PostFlowSeriesResponseDTODataAttributes
from openapi_client.models.post_flow_values_response_dto import PostFlowValuesResponseDTO
from openapi_client.models.post_flow_values_response_dto_data import PostFlowValuesResponseDTOData
from openapi_client.models.post_flow_values_response_dto_data_attributes import PostFlowValuesResponseDTODataAttributes
from openapi_client.models.post_flow_values_response_dto_data_relationships import PostFlowValuesResponseDTODataRelationships
from openapi_client.models.post_form_series_response_dto import PostFormSeriesResponseDTO
from openapi_client.models.post_form_series_response_dto_data import PostFormSeriesResponseDTOData
from openapi_client.models.post_form_series_response_dto_data_attributes import PostFormSeriesResponseDTODataAttributes
from openapi_client.models.post_form_values_response_dto import PostFormValuesResponseDTO
from openapi_client.models.post_form_values_response_dto_data import PostFormValuesResponseDTOData
from openapi_client.models.post_form_values_response_dto_data_attributes import PostFormValuesResponseDTODataAttributes
from openapi_client.models.post_image_response import PostImageResponse
from openapi_client.models.post_image_response_data import PostImageResponseData
from openapi_client.models.post_image_response_data_attributes import PostImageResponseDataAttributes
from openapi_client.models.post_list_create_response import PostListCreateResponse
from openapi_client.models.post_list_create_response_data import PostListCreateResponseData
from openapi_client.models.post_list_create_response_data_relationships import PostListCreateResponseDataRelationships
from openapi_client.models.post_list_create_response_data_relationships_flow_triggers import PostListCreateResponseDataRelationshipsFlowTriggers
from openapi_client.models.post_list_create_response_data_relationships_profiles import PostListCreateResponseDataRelationshipsProfiles
from openapi_client.models.post_metric_aggregate_response import PostMetricAggregateResponse
from openapi_client.models.post_metric_aggregate_response_data import PostMetricAggregateResponseData
from openapi_client.models.post_metric_aggregate_response_data_attributes import PostMetricAggregateResponseDataAttributes
from openapi_client.models.post_profile_import_job_response import PostProfileImportJobResponse
from openapi_client.models.post_profile_import_job_response_data import PostProfileImportJobResponseData
from openapi_client.models.post_profile_import_job_response_data_attributes import PostProfileImportJobResponseDataAttributes
from openapi_client.models.post_profile_import_job_response_data_relationships import PostProfileImportJobResponseDataRelationships
from openapi_client.models.post_profile_import_job_response_data_relationships_import_errors import PostProfileImportJobResponseDataRelationshipsImportErrors
from openapi_client.models.post_profile_import_job_response_data_relationships_import_errors_data_inner import PostProfileImportJobResponseDataRelationshipsImportErrorsDataInner
from openapi_client.models.post_profile_import_job_response_data_relationships_profiles import PostProfileImportJobResponseDataRelationshipsProfiles
from openapi_client.models.post_profile_import_job_response_data_relationships_profiles_data_inner import PostProfileImportJobResponseDataRelationshipsProfilesDataInner
from openapi_client.models.post_profile_merge_response import PostProfileMergeResponse
from openapi_client.models.post_profile_merge_response_data import PostProfileMergeResponseData
from openapi_client.models.post_profile_response import PostProfileResponse
from openapi_client.models.post_profile_response_data import PostProfileResponseData
from openapi_client.models.post_profile_response_data_attributes import PostProfileResponseDataAttributes
from openapi_client.models.post_segment_create_response import PostSegmentCreateResponse
from openapi_client.models.post_segment_create_response_data import PostSegmentCreateResponseData
from openapi_client.models.post_segment_series_response_dto import PostSegmentSeriesResponseDTO
from openapi_client.models.post_segment_series_response_dto_data import PostSegmentSeriesResponseDTOData
from openapi_client.models.post_segment_series_response_dto_data_attributes import PostSegmentSeriesResponseDTODataAttributes
from openapi_client.models.post_segment_values_response_dto import PostSegmentValuesResponseDTO
from openapi_client.models.post_segment_values_response_dto_data import PostSegmentValuesResponseDTOData
from openapi_client.models.post_segment_values_response_dto_data_attributes import PostSegmentValuesResponseDTODataAttributes
from openapi_client.models.post_tag_group_response import PostTagGroupResponse
from openapi_client.models.post_tag_group_response_data import PostTagGroupResponseData
from openapi_client.models.post_tag_group_response_data_attributes import PostTagGroupResponseDataAttributes
from openapi_client.models.post_tag_group_response_data_relationships import PostTagGroupResponseDataRelationships
from openapi_client.models.post_tag_response import PostTagResponse
from openapi_client.models.post_tag_response_data import PostTagResponseData
from openapi_client.models.post_tag_response_data_attributes import PostTagResponseDataAttributes
from openapi_client.models.post_tag_response_data_relationships import PostTagResponseDataRelationships
from openapi_client.models.post_tag_response_data_relationships_campaigns import PostTagResponseDataRelationshipsCampaigns
from openapi_client.models.post_template_response import PostTemplateResponse
from openapi_client.models.post_template_response_data import PostTemplateResponseData
from openapi_client.models.post_template_response_data_attributes import PostTemplateResponseDataAttributes
from openapi_client.models.post_universal_content_response import PostUniversalContentResponse
from openapi_client.models.post_universal_content_response_data import PostUniversalContentResponseData
from openapi_client.models.post_universal_content_response_data_attributes import PostUniversalContentResponseDataAttributes
from openapi_client.models.post_webhook_response import PostWebhookResponse
from openapi_client.models.post_webhook_response_data import PostWebhookResponseData
from openapi_client.models.post_webhook_response_data_attributes import PostWebhookResponseDataAttributes
from openapi_client.models.predictive_analytics import PredictiveAnalytics
from openapi_client.models.profile_bulk_import_job_enum import ProfileBulkImportJobEnum
from openapi_client.models.profile_create_query import ProfileCreateQuery
from openapi_client.models.profile_create_query_resource_object import ProfileCreateQueryResourceObject
from openapi_client.models.profile_create_query_resource_object_attributes import ProfileCreateQueryResourceObjectAttributes
from openapi_client.models.profile_enum import ProfileEnum
from openapi_client.models.profile_identifier_dto_resource_object import ProfileIdentifierDTOResourceObject
from openapi_client.models.profile_identifier_dto_resource_object_attributes import ProfileIdentifierDTOResourceObjectAttributes
from openapi_client.models.profile_import_job_create_query import ProfileImportJobCreateQuery
from openapi_client.models.profile_import_job_create_query_resource_object import ProfileImportJobCreateQueryResourceObject
from openapi_client.models.profile_import_job_create_query_resource_object_attributes import ProfileImportJobCreateQueryResourceObjectAttributes
from openapi_client.models.profile_import_job_create_query_resource_object_attributes_profiles import ProfileImportJobCreateQueryResourceObjectAttributesProfiles
from openapi_client.models.profile_import_job_create_query_resource_object_relationships import ProfileImportJobCreateQueryResourceObjectRelationships
from openapi_client.models.profile_import_job_create_query_resource_object_relationships_lists import ProfileImportJobCreateQueryResourceObjectRelationshipsLists
from openapi_client.models.profile_import_job_create_query_resource_object_relationships_lists_data_inner import ProfileImportJobCreateQueryResourceObjectRelationshipsListsDataInner
from openapi_client.models.profile_import_job_response_object_resource import ProfileImportJobResponseObjectResource
from openapi_client.models.profile_import_job_response_object_resource_attributes import ProfileImportJobResponseObjectResourceAttributes
from openapi_client.models.profile_location import ProfileLocation
from openapi_client.models.profile_merge_enum import ProfileMergeEnum
from openapi_client.models.profile_merge_query import ProfileMergeQuery
from openapi_client.models.profile_merge_query_resource_object import ProfileMergeQueryResourceObject
from openapi_client.models.profile_merge_query_resource_object_relationships import ProfileMergeQueryResourceObjectRelationships
from openapi_client.models.profile_merge_query_resource_object_relationships_profiles import ProfileMergeQueryResourceObjectRelationshipsProfiles
from openapi_client.models.profile_merge_query_resource_object_relationships_profiles_data_inner import ProfileMergeQueryResourceObjectRelationshipsProfilesDataInner
from openapi_client.models.profile_meta import ProfileMeta
from openapi_client.models.profile_meta_patch_properties import ProfileMetaPatchProperties
from openapi_client.models.profile_partial_update_query import ProfilePartialUpdateQuery
from openapi_client.models.profile_partial_update_query_resource_object import ProfilePartialUpdateQueryResourceObject
from openapi_client.models.profile_partial_update_query_resource_object_attributes import ProfilePartialUpdateQueryResourceObjectAttributes
from openapi_client.models.profile_response_object_resource_attributes import ProfileResponseObjectResourceAttributes
from openapi_client.models.profile_response_object_resource_extended import ProfileResponseObjectResourceExtended
from openapi_client.models.profile_response_object_resource_extended_attributes import ProfileResponseObjectResourceExtendedAttributes
from openapi_client.models.profile_subscription_bulk_create_job_enum import ProfileSubscriptionBulkCreateJobEnum
from openapi_client.models.profile_subscription_bulk_delete_job_enum import ProfileSubscriptionBulkDeleteJobEnum
from openapi_client.models.profile_subscription_create_query_resource_object import ProfileSubscriptionCreateQueryResourceObject
from openapi_client.models.profile_subscription_create_query_resource_object_attributes import ProfileSubscriptionCreateQueryResourceObjectAttributes
from openapi_client.models.profile_subscription_delete_query_resource_object import ProfileSubscriptionDeleteQueryResourceObject
from openapi_client.models.profile_subscription_delete_query_resource_object_attributes import ProfileSubscriptionDeleteQueryResourceObjectAttributes
from openapi_client.models.profile_suppression_bulk_create_job_enum import ProfileSuppressionBulkCreateJobEnum
from openapi_client.models.profile_suppression_bulk_delete_job_enum import ProfileSuppressionBulkDeleteJobEnum
from openapi_client.models.profile_suppression_create_query_resource_object import ProfileSuppressionCreateQueryResourceObject
from openapi_client.models.profile_suppression_create_query_resource_object_attributes import ProfileSuppressionCreateQueryResourceObjectAttributes
from openapi_client.models.profile_suppression_delete_query_resource_object import ProfileSuppressionDeleteQueryResourceObject
from openapi_client.models.profile_suppression_delete_query_resource_object_attributes import ProfileSuppressionDeleteQueryResourceObjectAttributes
from openapi_client.models.profile_upsert_query import ProfileUpsertQuery
from openapi_client.models.profile_upsert_query_resource_object import ProfileUpsertQueryResourceObject
from openapi_client.models.profile_upsert_query_resource_object_attributes import ProfileUpsertQueryResourceObjectAttributes
from openapi_client.models.push_channel import PushChannel
from openapi_client.models.push_marketing import PushMarketing
from openapi_client.models.push_profile_upsert_query_resource_object import PushProfileUpsertQueryResourceObject
from openapi_client.models.push_profile_upsert_query_resource_object_attributes import PushProfileUpsertQueryResourceObjectAttributes
from openapi_client.models.push_token_create_query import PushTokenCreateQuery
from openapi_client.models.push_token_create_query_resource_object import PushTokenCreateQueryResourceObject
from openapi_client.models.push_token_create_query_resource_object_attributes import PushTokenCreateQueryResourceObjectAttributes
from openapi_client.models.push_token_create_query_resource_object_attributes_profile import PushTokenCreateQueryResourceObjectAttributesProfile
from openapi_client.models.push_token_enum import PushTokenEnum
from openapi_client.models.relationship_links import RelationshipLinks
from openapi_client.models.render_options_sub_object import RenderOptionsSubObject
from openapi_client.models.review_enum import ReviewEnum
from openapi_client.models.review_product_dto import ReviewProductDTO
from openapi_client.models.review_public_reply import ReviewPublicReply
from openapi_client.models.review_response_dto20240715_object_resource import ReviewResponseDTO20240715ObjectResource
from openapi_client.models.review_response_dto20240715_object_resource_attributes import ReviewResponseDTO20240715ObjectResourceAttributes
from openapi_client.models.sms_render_options import SMSRenderOptions
from openapi_client.models.sms_subscription_parameters import SMSSubscriptionParameters
from openapi_client.models.sto_schedule_options import STOScheduleOptions
from openapi_client.models.segment_create_query import SegmentCreateQuery
from openapi_client.models.segment_create_query_resource_object import SegmentCreateQueryResourceObject
from openapi_client.models.segment_create_query_resource_object_attributes import SegmentCreateQueryResourceObjectAttributes
from openapi_client.models.segment_definition import SegmentDefinition
from openapi_client.models.segment_enum import SegmentEnum
from openapi_client.models.segment_list_response_object_resource import SegmentListResponseObjectResource
from openapi_client.models.segment_list_response_object_resource_attributes import SegmentListResponseObjectResourceAttributes
from openapi_client.models.segment_member_response_object_resource_attributes import SegmentMemberResponseObjectResourceAttributes
from openapi_client.models.segment_member_response_object_resource_extended import SegmentMemberResponseObjectResourceExtended
from openapi_client.models.segment_member_response_object_resource_extended_attributes import SegmentMemberResponseObjectResourceExtendedAttributes
from openapi_client.models.segment_partial_update_query import SegmentPartialUpdateQuery
from openapi_client.models.segment_partial_update_query_resource_object import SegmentPartialUpdateQueryResourceObject
from openapi_client.models.segment_partial_update_query_resource_object_attributes import SegmentPartialUpdateQueryResourceObjectAttributes
from openapi_client.models.segment_response_object_resource import SegmentResponseObjectResource
from openapi_client.models.segment_retrieve_response_object_resource_attributes import SegmentRetrieveResponseObjectResourceAttributes
from openapi_client.models.segment_retrieve_response_object_resource_extended import SegmentRetrieveResponseObjectResourceExtended
from openapi_client.models.segment_retrieve_response_object_resource_extended_attributes import SegmentRetrieveResponseObjectResourceExtendedAttributes
from openapi_client.models.segment_series_report_enum import SegmentSeriesReportEnum
from openapi_client.models.segment_series_request_dto import SegmentSeriesRequestDTO
from openapi_client.models.segment_series_request_dto_resource_object import SegmentSeriesRequestDTOResourceObject
from openapi_client.models.segment_series_request_dto_resource_object_attributes import SegmentSeriesRequestDTOResourceObjectAttributes
from openapi_client.models.segment_values_report_enum import SegmentValuesReportEnum
from openapi_client.models.segment_values_request_dto import SegmentValuesRequestDTO
from openapi_client.models.segment_values_request_dto_resource_object import SegmentValuesRequestDTOResourceObject
from openapi_client.models.segment_values_request_dto_resource_object_attributes import SegmentValuesRequestDTOResourceObjectAttributes
from openapi_client.models.send_options import SendOptions
from openapi_client.models.send_strategy_sub_object import SendStrategySubObject
from openapi_client.models.send_time_sub_object import SendTimeSubObject
from openapi_client.models.series_data import SeriesData
from openapi_client.models.server_bis_subscription_create_query import ServerBISSubscriptionCreateQuery
from openapi_client.models.server_bis_subscription_create_query_resource_object import ServerBISSubscriptionCreateQueryResourceObject
from openapi_client.models.server_bis_subscription_create_query_resource_object_attributes import ServerBISSubscriptionCreateQueryResourceObjectAttributes
from openapi_client.models.server_bis_subscription_create_query_resource_object_attributes_profile import ServerBISSubscriptionCreateQueryResourceObjectAttributesProfile
from openapi_client.models.server_bis_subscription_create_query_resource_object_relationships import ServerBISSubscriptionCreateQueryResourceObjectRelationships
from openapi_client.models.server_bis_subscription_create_query_resource_object_relationships_variant import ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariant
from openapi_client.models.server_bis_subscription_create_query_resource_object_relationships_variant_data import ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariantData
from openapi_client.models.static_schedule_options import StaticScheduleOptions
from openapi_client.models.street_address import StreetAddress
from openapi_client.models.subscription_channels import SubscriptionChannels
from openapi_client.models.subscription_create_job_create_query import SubscriptionCreateJobCreateQuery
from openapi_client.models.subscription_create_job_create_query_resource_object import SubscriptionCreateJobCreateQueryResourceObject
from openapi_client.models.subscription_create_job_create_query_resource_object_attributes import SubscriptionCreateJobCreateQueryResourceObjectAttributes
from openapi_client.models.subscription_create_job_create_query_resource_object_attributes_profiles import SubscriptionCreateJobCreateQueryResourceObjectAttributesProfiles
from openapi_client.models.subscription_create_job_create_query_resource_object_relationships import SubscriptionCreateJobCreateQueryResourceObjectRelationships
from openapi_client.models.subscription_create_job_create_query_resource_object_relationships_list import SubscriptionCreateJobCreateQueryResourceObjectRelationshipsList
from openapi_client.models.subscription_create_job_create_query_resource_object_relationships_list_data import SubscriptionCreateJobCreateQueryResourceObjectRelationshipsListData
from openapi_client.models.subscription_delete_job_create_query import SubscriptionDeleteJobCreateQuery
from openapi_client.models.subscription_delete_job_create_query_resource_object import SubscriptionDeleteJobCreateQueryResourceObject
from openapi_client.models.subscription_delete_job_create_query_resource_object_attributes import SubscriptionDeleteJobCreateQueryResourceObjectAttributes
from openapi_client.models.subscription_delete_job_create_query_resource_object_attributes_profiles import SubscriptionDeleteJobCreateQueryResourceObjectAttributesProfiles
from openapi_client.models.subscription_delete_job_create_query_resource_object_relationships import SubscriptionDeleteJobCreateQueryResourceObjectRelationships
from openapi_client.models.subscription_delete_job_create_query_resource_object_relationships_list import SubscriptionDeleteJobCreateQueryResourceObjectRelationshipsList
from openapi_client.models.subscription_delete_job_create_query_resource_object_relationships_list_data import SubscriptionDeleteJobCreateQueryResourceObjectRelationshipsListData
from openapi_client.models.subscription_parameters import SubscriptionParameters
from openapi_client.models.subscriptions import Subscriptions
from openapi_client.models.suppression_create_job_create_query import SuppressionCreateJobCreateQuery
from openapi_client.models.suppression_create_job_create_query_resource_object import SuppressionCreateJobCreateQueryResourceObject
from openapi_client.models.suppression_create_job_create_query_resource_object_attributes import SuppressionCreateJobCreateQueryResourceObjectAttributes
from openapi_client.models.suppression_create_job_create_query_resource_object_attributes_profiles import SuppressionCreateJobCreateQueryResourceObjectAttributesProfiles
from openapi_client.models.suppression_create_job_create_query_resource_object_relationships import SuppressionCreateJobCreateQueryResourceObjectRelationships
from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_list import SuppressionCreateJobCreateQueryResourceObjectRelationshipsList
from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_list_data import SuppressionCreateJobCreateQueryResourceObjectRelationshipsListData
from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_segment import SuppressionCreateJobCreateQueryResourceObjectRelationshipsSegment
from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_segment_data import SuppressionCreateJobCreateQueryResourceObjectRelationshipsSegmentData
from openapi_client.models.suppression_delete_job_create_query import SuppressionDeleteJobCreateQuery
from openapi_client.models.suppression_delete_job_create_query_resource_object import SuppressionDeleteJobCreateQueryResourceObject
from openapi_client.models.suppression_delete_job_create_query_resource_object_attributes import SuppressionDeleteJobCreateQueryResourceObjectAttributes
from openapi_client.models.suppression_delete_job_create_query_resource_object_attributes_profiles import SuppressionDeleteJobCreateQueryResourceObjectAttributesProfiles
from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships import SuppressionDeleteJobCreateQueryResourceObjectRelationships
from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_list import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsList
from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_list_data import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsListData
from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_segment import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsSegment
from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_segment_data import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsSegmentData
from openapi_client.models.tag_campaign_op import TagCampaignOp
from openapi_client.models.tag_campaign_op_data_inner import TagCampaignOpDataInner
from openapi_client.models.tag_create_query import TagCreateQuery
from openapi_client.models.tag_create_query_resource_object import TagCreateQueryResourceObject
from openapi_client.models.tag_create_query_resource_object_relationships import TagCreateQueryResourceObjectRelationships
from openapi_client.models.tag_create_query_resource_object_relationships_tag_group import TagCreateQueryResourceObjectRelationshipsTagGroup
from openapi_client.models.tag_create_query_resource_object_relationships_tag_group_data import TagCreateQueryResourceObjectRelationshipsTagGroupData
from openapi_client.models.tag_enum import TagEnum
from openapi_client.models.tag_flow_op import TagFlowOp
from openapi_client.models.tag_flow_op_data_inner import TagFlowOpDataInner
from openapi_client.models.tag_group_create_query import TagGroupCreateQuery
from openapi_client.models.tag_group_create_query_resource_object import TagGroupCreateQueryResourceObject
from openapi_client.models.tag_group_create_query_resource_object_attributes import TagGroupCreateQueryResourceObjectAttributes
from openapi_client.models.tag_group_enum import TagGroupEnum
from openapi_client.models.tag_group_response_object_resource import TagGroupResponseObjectResource
from openapi_client.models.tag_group_response_object_resource_attributes import TagGroupResponseObjectResourceAttributes
from openapi_client.models.tag_group_update_query import TagGroupUpdateQuery
from openapi_client.models.tag_group_update_query_resource_object import TagGroupUpdateQueryResourceObject
from openapi_client.models.tag_group_update_query_resource_object_attributes import TagGroupUpdateQueryResourceObjectAttributes
from openapi_client.models.tag_list_op import TagListOp
from openapi_client.models.tag_list_op_data_inner import TagListOpDataInner
from openapi_client.models.tag_response_object_resource import TagResponseObjectResource
from openapi_client.models.tag_response_object_resource_attributes import TagResponseObjectResourceAttributes
from openapi_client.models.tag_segment_op import TagSegmentOp
from openapi_client.models.tag_segment_op_data_inner import TagSegmentOpDataInner
from openapi_client.models.tag_update_query import TagUpdateQuery
from openapi_client.models.tag_update_query_resource_object import TagUpdateQueryResourceObject
from openapi_client.models.template_clone_query import TemplateCloneQuery
from openapi_client.models.template_clone_query_resource_object import TemplateCloneQueryResourceObject
from openapi_client.models.template_clone_query_resource_object_attributes import TemplateCloneQueryResourceObjectAttributes
from openapi_client.models.template_create_query import TemplateCreateQuery
from openapi_client.models.template_create_query_resource_object import TemplateCreateQueryResourceObject
from openapi_client.models.template_create_query_resource_object_attributes import TemplateCreateQueryResourceObjectAttributes
from openapi_client.models.template_enum import TemplateEnum
from openapi_client.models.template_render_query import TemplateRenderQuery
from openapi_client.models.template_render_query_resource_object import TemplateRenderQueryResourceObject
from openapi_client.models.template_render_query_resource_object_attributes import TemplateRenderQueryResourceObjectAttributes
from openapi_client.models.template_response_object_resource import TemplateResponseObjectResource
from openapi_client.models.template_response_object_resource_attributes import TemplateResponseObjectResourceAttributes
from openapi_client.models.template_universal_content_enum import TemplateUniversalContentEnum
from openapi_client.models.template_update_query import TemplateUpdateQuery
from openapi_client.models.template_update_query_resource_object import TemplateUpdateQueryResourceObject
from openapi_client.models.template_update_query_resource_object_attributes import TemplateUpdateQueryResourceObjectAttributes
from openapi_client.models.throttled_schedule_options import ThrottledScheduleOptions
from openapi_client.models.tracking_param_dto import TrackingParamDTO
from openapi_client.models.tracking_setting_enum import TrackingSettingEnum
from openapi_client.models.tracking_setting_partial_update_query import TrackingSettingPartialUpdateQuery
from openapi_client.models.tracking_setting_partial_update_query_resource_object import TrackingSettingPartialUpdateQueryResourceObject
from openapi_client.models.tracking_setting_partial_update_query_resource_object_attributes import TrackingSettingPartialUpdateQueryResourceObjectAttributes
from openapi_client.models.tracking_setting_response_object_resource import TrackingSettingResponseObjectResource
from openapi_client.models.tracking_setting_response_object_resource_attributes import TrackingSettingResponseObjectResourceAttributes
from openapi_client.models.universal_content_create_query import UniversalContentCreateQuery
from openapi_client.models.universal_content_create_query_resource_object import UniversalContentCreateQueryResourceObject
from openapi_client.models.universal_content_create_query_resource_object_attributes import UniversalContentCreateQueryResourceObjectAttributes
from openapi_client.models.universal_content_partial_update_query import UniversalContentPartialUpdateQuery
from openapi_client.models.universal_content_partial_update_query_resource_object import UniversalContentPartialUpdateQueryResourceObject
from openapi_client.models.universal_content_partial_update_query_resource_object_attributes import UniversalContentPartialUpdateQueryResourceObjectAttributes
from openapi_client.models.universal_content_response_object_resource import UniversalContentResponseObjectResource
from openapi_client.models.universal_content_response_object_resource_attributes import UniversalContentResponseObjectResourceAttributes
from openapi_client.models.values_data import ValuesData
from openapi_client.models.webhook_create_query import WebhookCreateQuery
from openapi_client.models.webhook_create_query_resource_object import WebhookCreateQueryResourceObject
from openapi_client.models.webhook_create_query_resource_object_attributes import WebhookCreateQueryResourceObjectAttributes
from openapi_client.models.webhook_create_query_resource_object_relationships import WebhookCreateQueryResourceObjectRelationships
from openapi_client.models.webhook_create_query_resource_object_relationships_webhook_topics import WebhookCreateQueryResourceObjectRelationshipsWebhookTopics
from openapi_client.models.webhook_create_query_resource_object_relationships_webhook_topics_data_inner import WebhookCreateQueryResourceObjectRelationshipsWebhookTopicsDataInner
from openapi_client.models.webhook_enum import WebhookEnum
from openapi_client.models.webhook_partial_update_query import WebhookPartialUpdateQuery
from openapi_client.models.webhook_partial_update_query_resource_object import WebhookPartialUpdateQueryResourceObject
from openapi_client.models.webhook_partial_update_query_resource_object_attributes import WebhookPartialUpdateQueryResourceObjectAttributes
from openapi_client.models.webhook_response_object_resource import WebhookResponseObjectResource
from openapi_client.models.webhook_response_object_resource_attributes import WebhookResponseObjectResourceAttributes
from openapi_client.models.webhook_topic_enum import WebhookTopicEnum
from openapi_client.models.webhook_topic_response_object_resource import WebhookTopicResponseObjectResource



# coding: utf-8

"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    The version of the OpenAPI document: 2024-10-15
    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from openapi_client.models.predictive_analytics import PredictiveAnalytics
from openapi_client.models.profile_location import ProfileLocation
from openapi_client.models.subscriptions import Subscriptions
from typing import Optional, Set
from typing_extensions import Self

class SegmentMemberResponseObjectResourceExtendedAttributes(BaseModel):
    """
    SegmentMemberResponseObjectResourceExtendedAttributes
    """ # noqa: E501
    email: Optional[StrictStr] = Field(default=None, description="Individual's email address")
    phone_number: Optional[StrictStr] = Field(default=None, description="Individual's phone number in E.164 format")
    external_id: Optional[StrictStr] = Field(default=None, description="A unique identifier used by customers to associate Klaviyo profiles with profiles in an external system, such as a point-of-sale system. Format varies based on the external system.")
    first_name: Optional[StrictStr] = Field(default=None, description="Individual's first name")
    last_name: Optional[StrictStr] = Field(default=None, description="Individual's last name")
    organization: Optional[StrictStr] = Field(default=None, description="Name of the company or organization within the company for whom the individual works")
    locale: Optional[StrictStr] = Field(default=None, description="The locale of the profile, in the IETF BCP 47 language tag format like (ISO 639-1/2)-(ISO 3166 alpha-2)")
    title: Optional[StrictStr] = Field(default=None, description="Individual's job title")
    image: Optional[StrictStr] = Field(default=None, description="URL pointing to the location of a profile image")
    created: Optional[datetime] = Field(default=None, description="Date and time when the profile was created, in ISO 8601 format (YYYY-MM-DDTHH:MM:SS.mmmmmm)")
    updated: Optional[datetime] = Field(default=None, description="Date and time when the profile was last updated, in ISO 8601 format (YYYY-MM-DDTHH:MM:SS.mmmmmm)")
    last_event_date: Optional[datetime] = Field(default=None, description="Date and time of the most recent event the triggered an update to the profile, in ISO 8601 format (YYYY-MM-DDTHH:MM:SS.mmmmmm)")
    location: Optional[ProfileLocation] = None
    properties: Optional[Dict[str, Any]] = Field(default=None, description="An object containing key/value pairs for any custom properties assigned to this profile")
    joined_group_at: Optional[datetime] = Field(description="The datetime when this profile most recently joined the segment.")
    subscriptions: Optional[Subscriptions] = None
    predictive_analytics: Optional[PredictiveAnalytics] = None
    __properties: ClassVar[List[str]] = ["email", "phone_number", "external_id", "first_name", "last_name", "organization", "locale", "title", "image", "created", "updated", "last_event_date", "location", "properties", "joined_group_at", "subscriptions", "predictive_analytics"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SegmentMemberResponseObjectResourceExtendedAttributes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of location
        if self.location:
            _dict['location'] = self.location.to_dict()
        # override the default output from pydantic by calling `to_dict()` of subscriptions
        if self.subscriptions:
            _dict['subscriptions'] = self.subscriptions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of predictive_analytics
        if self.predictive_analytics:
            _dict['predictive_analytics'] = self.predictive_analytics.to_dict()
        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if phone_number (nullable) is None
        # and model_fields_set contains the field
        if self.phone_number is None and "phone_number" in self.model_fields_set:
            _dict['phone_number'] = None

        # set to None if external_id (nullable) is None
        # and model_fields_set contains the field
        if self.external_id is None and "external_id" in self.model_fields_set:
            _dict['external_id'] = None

        # set to None if first_name (nullable) is None
        # and model_fields_set contains the field
        if self.first_name is None and "first_name" in self.model_fields_set:
            _dict['first_name'] = None

        # set to None if last_name (nullable) is None
        # and model_fields_set contains the field
        if self.last_name is None and "last_name" in self.model_fields_set:
            _dict['last_name'] = None

        # set to None if organization (nullable) is None
        # and model_fields_set contains the field
        if self.organization is None and "organization" in self.model_fields_set:
            _dict['organization'] = None

        # set to None if locale (nullable) is None
        # and model_fields_set contains the field
        if self.locale is None and "locale" in self.model_fields_set:
            _dict['locale'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if image (nullable) is None
        # and model_fields_set contains the field
        if self.image is None and "image" in self.model_fields_set:
            _dict['image'] = None

        # set to None if created (nullable) is None
        # and model_fields_set contains the field
        if self.created is None and "created" in self.model_fields_set:
            _dict['created'] = None

        # set to None if updated (nullable) is None
        # and model_fields_set contains the field
        if self.updated is None and "updated" in self.model_fields_set:
            _dict['updated'] = None

        # set to None if last_event_date (nullable) is None
        # and model_fields_set contains the field
        if self.last_event_date is None and "last_event_date" in self.model_fields_set:
            _dict['last_event_date'] = None

        # set to None if properties (nullable) is None
        # and model_fields_set contains the field
        if self.properties is None and "properties" in self.model_fields_set:
            _dict['properties'] = None

        # set to None if joined_group_at (nullable) is None
        # and model_fields_set contains the field
        if self.joined_group_at is None and "joined_group_at" in self.model_fields_set:
            _dict['joined_group_at'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SegmentMemberResponseObjectResourceExtendedAttributes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "email": obj.get("email"),
            "phone_number": obj.get("phone_number"),
            "external_id": obj.get("external_id"),
            "first_name": obj.get("first_name"),
            "last_name": obj.get("last_name"),
            "organization": obj.get("organization"),
            "locale": obj.get("locale"),
            "title": obj.get("title"),
            "image": obj.get("image"),
            "created": obj.get("created"),
            "updated": obj.get("updated"),
            "last_event_date": obj.get("last_event_date"),
            "location": ProfileLocation.from_dict(obj["location"]) if obj.get("location") is not None else None,
            "properties": obj.get("properties"),
            "joined_group_at": obj.get("joined_group_at"),
            "subscriptions": Subscriptions.from_dict(obj["subscriptions"]) if obj.get("subscriptions") is not None else None,
            "predictive_analytics": PredictiveAnalytics.from_dict(obj["predictive_analytics"]) if obj.get("predictive_analytics") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    The version of the OpenAPI document: 2024-10-15
    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from openapi_client.models.server_bis_subscription_create_query_resource_object_attributes_profile import ServerBISSubscriptionCreateQueryResourceObjectAttributesProfile
from typing import Optional, Set
from typing_extensions import Self

class ServerBISSubscriptionCreateQueryResourceObjectAttributes(BaseModel):
    """
    ServerBISSubscriptionCreateQueryResourceObjectAttributes
    """ # noqa: E501
    channels: List[StrictStr] = Field(description="The channel(s) through which the profile would like to receive the back in stock notification. This can be leveraged within a back in stock flow to notify the subscriber through their preferred channel(s).")
    profile: Optional[ServerBISSubscriptionCreateQueryResourceObjectAttributesProfile] = None
    __properties: ClassVar[List[str]] = ["channels", "profile"]

    @field_validator('channels')
    def channels_validate_enum(cls, value):
        """Validates the enum"""
        for i in value:
            if i not in set(['EMAIL', 'PUSH', 'SMS']):
                raise ValueError("each list item must be one of ('EMAIL', 'PUSH', 'SMS')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServerBISSubscriptionCreateQueryResourceObjectAttributes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of profile
        if self.profile:
            _dict['profile'] = self.profile.to_dict()
        # set to None if profile (nullable) is None
        # and model_fields_set contains the field
        if self.profile is None and "profile" in self.model_fields_set:
            _dict['profile'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServerBISSubscriptionCreateQueryResourceObjectAttributes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "channels": obj.get("channels"),
            "profile": ServerBISSubscriptionCreateQueryResourceObjectAttributesProfile.from_dict(obj["profile"]) if obj.get("profile") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    The version of the OpenAPI document: 2024-10-15
    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PostProfileImportJobResponseDataAttributes(BaseModel):
    """
    PostProfileImportJobResponseDataAttributes
    """ # noqa: E501
    status: StrictStr = Field(description="Status of the asynchronous job.")
    created_at: datetime = Field(description="The date and time the job was created in ISO 8601 format (YYYY-MM-DDTHH:MM:SS.mmmmmm).")
    total_count: StrictInt = Field(description="The total number of operations to be processed by the job. See `completed_count` for the job's current progress.")
    completed_count: Optional[StrictInt] = Field(default=0, description="The total number of operations that have been completed by the job.")
    failed_count: Optional[StrictInt] = Field(default=0, description="The total number of operations that have failed as part of the job.")
    completed_at: Optional[datetime] = Field(default=None, description="Date and time the job was completed in ISO 8601 format (YYYY-MM-DDTHH:MM:SS.mmmmmm).")
    expires_at: Optional[datetime] = Field(default=None, description="Date and time the job expires in ISO 8601 format (YYYY-MM-DDTHH:MM:SS.mmmmmm).")
    started_at: Optional[datetime] = Field(default=None, description="Date and time the job started processing in ISO 8601 format (YYYY-MM-DDTHH:MM:SS.mmmmmm).")
    __properties: ClassVar[List[str]] = ["status", "created_at", "total_count", "completed_count", "failed_count", "completed_at", "expires_at", "started_at"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['cancelled', 'complete', 'processing', 'queued']):
            raise ValueError("must be one of enum values ('cancelled', 'complete', 'processing', 'queued')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PostProfileImportJobResponseDataAttributes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if completed_count (nullable) is None
        # and model_fields_set contains the field
        if self.completed_count is None and "completed_count" in self.model_fields_set:
            _dict['completed_count'] = None

        # set to None if failed_count (nullable) is None
        # and model_fields_set contains the field
        if self.failed_count is None and "failed_count" in self.model_fields_set:
            _dict['failed_count'] = None

        # set to None if completed_at (nullable) is None
        # and model_fields_set contains the field
        if self.completed_at is None and "completed_at" in self.model_fields_set:
            _dict['completed_at'] = None

        # set to None if expires_at (nullable) is None
        # and model_fields_set contains the field
        if self.expires_at is None and "expires_at" in self.model_fields_set:
            _dict['expires_at'] = None

        # set to None if started_at (nullable) is None
        # and model_fields_set contains the field
        if self.started_at is None and "started_at" in self.model_fields_set:
            _dict['started_at'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PostProfileImportJobResponseDataAttributes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "status": obj.get("status"),
            "created_at": obj.get("created_at"),
            "total_count": obj.get("total_count"),
            "completed_count": obj.get("completed_count") if obj.get("completed_count") is not None else 0,
            "failed_count": obj.get("failed_count") if obj.get("failed_count") is not None else 0,
            "completed_at": obj.get("completed_at"),
            "expires_at": obj.get("expires_at"),
            "started_at": obj.get("started_at")
        })
        return _obj


